@@ -33,7 +33,9 @@
 
 #include <guppi-memory.h>
 #include <guppi-seq-string.h>
+#include <guppi-seq-string-core.h>
 #include <guppi-seq-scalar.h>
+#include <guppi-seq-scalar-core.h>
 #include <guppi-root-group-item.h>
 #include <guppi-root-group-state.h>
 #include <guppi-group-view-layout.h>
@@ -51,8 +53,8 @@
 #define HAIR_WIDTH	.5
 #define GAP		3.6	/* 1/20 inch */
 
-static GupGnmPlotDescriptor const *
-plot_get_descriptor (xmlNode *plot)
+GupGnmPlotDescriptor const *
+gup_gnm_plot_get_descriptor (xmlNode *plot)
 {
 	extern GupGnmPlotDescriptor gup_gnm_scatter_plot_type;
 	extern GupGnmPlotDescriptor gup_gnm_pie_plot_type;
@@ -208,7 +210,7 @@ cb_series_set_dim (GupGnmGraph *graph,
 	/* store the new name */
 	if (is_label)
 		guppi_seq_string_set_nc (
-			GUPPI_SEQ_STRING (graph->series.names),
+			graph->series.names,
 			ID, gup_gnm_series_calc_name (series, ID, graph));
 
 	/* If this is a shared dim change the other members of this plot */
@@ -216,7 +218,7 @@ cb_series_set_dim (GupGnmGraph *graph,
 		int i;
 		xmlNode *ptr;
 		GupGnmPlotDescriptor const *descriptor =
-			plot_get_descriptor (plot);
+			gup_gnm_plot_get_descriptor (plot);
 
 		g_return_val_if_fail (descriptor != NULL, TRUE);
 		for (i = 0; descriptor->spec [i].display_name != NULL ; i++) {
@@ -243,7 +245,7 @@ cb_series_set_dim (GupGnmGraph *graph,
  * gup_gnm_graph_set_series_dim :
  *
  * Find the series with the supplied ID and change the specified dimension.
- * Handle special cases of shared dimensions, and names.
+ * Handle special case of shared dimensions, and names.
  *
  * returns TRUE if things succeeded.
  */
@@ -307,11 +309,13 @@ gup_gnm_graph_make_plot (GupGnmGraph *graph)
 	/* Models */
 	GuppiElementState *root_state;
 	GuppiElementState *plot_state, *legend_state;
+	GuppiElementState *compassbox_state;
 	GSList *plot_states = NULL;
 
 	/* View Objects */
 	GuppiGroupView	 *root_view;
 	GuppiElementView *plot_view, *legend_view = NULL;
+	GuppiElementView *compassbox_view;
 	GuppiElementView *frame_view, *x_axis_view, *y_axis_view;
 	
 	GuppiGroupView *group_view;
@@ -329,9 +333,9 @@ gup_gnm_graph_make_plot (GupGnmGraph *graph)
 		if (strcmp (plot->name, "Plot"))
 			continue;
 
-		if (NULL != (descriptor = plot_get_descriptor (plot))) {
+		if (NULL != (descriptor = gup_gnm_plot_get_descriptor (plot))) {
 			plot_states = g_slist_concat (plot_states,
-				descriptor->plot (graph, plot));
+						      descriptor->plot (graph, plot));
 			singleton = descriptor->singleton;
 		}
 	}
@@ -360,44 +364,44 @@ gup_gnm_graph_make_plot (GupGnmGraph *graph)
 		if (tmp != NULL) {
 			legend_location = guppi_str2compass (tmp);
 			xmlFree (tmp);
-
-			legend_state = guppi_element_state_new("legend",
-				"swatch_width",   6.,
-				"swatch_height",  6.,
-				"edge_thickness", HAIR_WIDTH,
-				"edge_margin",	  guppi_in2pt(1/16.0),
-				NULL);
-			legend_view = guppi_element_state_make_view (legend_state);
-			guppi_unref (legend_state);
-
-			guppi_element_state_changed_delayed (plot_state);
-
-			if (singleton) {
-
-				/* This is an evil, pie-specific hack */
-				if (!strcmp (descriptor->name, "Pie")) {
-
-					GuppiData *d = NULL;
-					GuppiColorPalette *palette = NULL;
-					guppi_element_state_get (plot_state,
-						"label_data", &d,
-						"slice_colors", &palette,
-						NULL);
-					guppi_element_state_set (legend_state,
-						"labels", d,
-						"swatch_colors", palette, 
-						NULL);
-				}
-				
-			} else if (graph->series.names) {
-				guppi_element_state_set (legend_state,
-					"labels",	 graph->series.names,
-					"swatch_colors", graph->series.colours,
-					NULL);
-			}
 		}
 	}
 
+	legend_state = guppi_element_state_new("legend",
+					       "swatch_width",   6.,
+					       "swatch_height",  6.,
+					       "edge_thickness", HAIR_WIDTH,
+					       "edge_margin",	  guppi_in2pt(1/16.0),
+					       NULL);
+	legend_view = guppi_element_state_make_view (legend_state);
+	guppi_unref (legend_state);
+	
+	/* guppi_element_state_changed_delayed (plot_state); */
+	
+	if (singleton) {
+		
+		/* This is an evil, pie-specific hack */
+		if (!strcmp (descriptor->name, "Pie")) {
+			
+			GuppiData *d = NULL;
+			GuppiColorPalette *palette = NULL;
+			guppi_element_state_get (plot_state,
+						 "label_data", &d,
+						 "slice_colors", &palette,
+						 NULL);
+			guppi_element_state_set (legend_state,
+						 "labels", d,
+						 "swatch_colors", palette, 
+						 NULL);
+		}
+		
+	} else if (graph->series.names != NULL) {
+		guppi_element_state_set (legend_state,
+					 "labels",	 graph->series.names,
+					 "swatch_colors", graph->series.colours,
+					 NULL);
+	}
+
 	/* Frame (i.e. Grid Lines) */
 	if (singleton) {
 		frame_view = NULL;
@@ -414,6 +418,13 @@ gup_gnm_graph_make_plot (GupGnmGraph *graph)
 		guppi_unref (frame_state);
 	}
 
+	/* Compass Box */
+	compassbox_state = guppi_element_state_new ("compass-box",
+						    "position", legend_location,
+						    NULL);
+	compassbox_view  = guppi_element_view_new (compassbox_state, NULL);
+	guppi_unref (compassbox_state);
+
 	/* Axes */
 	if (singleton) {
 		x_axis_view = y_axis_view = NULL;
@@ -449,8 +460,8 @@ gup_gnm_graph_make_plot (GupGnmGraph *graph)
 		static guint32 const grey = RGBA_TO_UINT(0xd7,0xd7,0xd7,0xff);
 		GuppiElementState *back_state = guppi_element_state_new ("background",
 #ifdef EYE_CANDY
-			"color", 0xe0e0ffff,
-			"color_final", 0xffffffff,
+			"color", 	0xe0e0ffff,
+			"color_final",	0xffffffff,
 			"gradient_start", GUPPI_SOUTH,
 #else
 			"color",	grey,
@@ -502,38 +513,10 @@ gup_gnm_graph_make_plot (GupGnmGraph *graph)
 		g_slist_free (plot_states);
 	}
 
-	if (legend_location == GUPPI_NORTH) {
-		guppi_group_view_layout_flush_top (root_view,
-			legend_view, GAP);
-		guppi_group_view_layout_vertically_adjacent (root_view,
-							     legend_view, (GuppiElementView *) group_view, GAP);
-		guppi_group_view_layout_center_horizontally (root_view, legend_view);
-	} else
-		guppi_group_view_layout_flush_top (root_view, (GuppiElementView *) group_view, GAP);
-	if (legend_location == GUPPI_SOUTH) {
-		guppi_group_view_layout_flush_bottom (root_view,
-			legend_view, GAP);
-		guppi_group_view_layout_vertically_adjacent (root_view,
-			(GuppiElementView *) group_view, legend_view, GAP);
-		guppi_group_view_layout_center_horizontally (root_view, legend_view);
-	} else
-		guppi_group_view_layout_flush_bottom (root_view, (GuppiElementView *) group_view, GAP);
-	if (legend_location == GUPPI_EAST) {
-		guppi_group_view_layout_flush_right (root_view,
-			legend_view, GAP);
-		guppi_group_view_layout_horizontally_adjacent (root_view,
-			(GuppiElementView *) group_view, legend_view, GAP);
-		guppi_group_view_layout_center_vertically (root_view, legend_view);
-	} else
-		guppi_group_view_layout_flush_right (root_view, (GuppiElementView *) group_view, GAP);
-	if (legend_location == GUPPI_WEST) {
-		guppi_group_view_layout_flush_left (root_view,
-			legend_view, GAP);
-		guppi_group_view_layout_horizontally_adjacent (root_view,
-			legend_view, (GuppiElementView *) group_view, GAP);
-		guppi_group_view_layout_center_vertically (root_view, legend_view);
-	} else
-		guppi_group_view_layout_flush_left (root_view, (GuppiElementView *) group_view, GAP);
+	guppi_group_view_add ((GuppiGroupView *) compassbox_view, legend_view);
+	guppi_group_view_add ((GuppiGroupView *) compassbox_view, (GuppiElementView *) group_view);
+
+	guppi_group_view_layout_fill (root_view, compassbox_view, GAP, GAP, GAP, GAP);
 
 	guppi_element_view_set_preferred_view_all (plot_view);
 
@@ -550,13 +533,13 @@ gup_gnm_graph_make_plot (GupGnmGraph *graph)
 	return GUPPI_ROOT_GROUP_VIEW (root_view);
 }
 /**
- * gup_gnm_graph_get_plot :
+ * gup_gnm_graph_get_view :
  * @graph :
  *
- * Get a possibly cached plot.
+ * Get a possibly cached view.
  */
 GuppiRootGroupView *
-gup_gnm_graph_get_plot (GupGnmGraph *graph)
+gup_gnm_graph_get_view (GupGnmGraph *graph)
 {
 	if (graph->plot == NULL)
 		graph->plot = gup_gnm_graph_make_plot (graph);
@@ -611,7 +594,7 @@ gup_gnm_graph_construct (GupGnmGraph *graph, GupGnmManager *manager)
 	graph->views = NULL;
 	graph->spec = NULL;
 	graph->wrapper_sequences = NULL;
-	graph->series.names = guppi_seq_string_new ();
+	graph->series.names = guppi_seq_string_core_new ();
 	graph->series.colours = guppi_color_palette_new ();
 	graph->series.markers = g_array_new (FALSE, TRUE, sizeof (GuppiMarker));
 }
@@ -644,15 +627,12 @@ cb_store_series_name (GupGnmGraph *graph,
 		      gpointer user)
 {
 	SeriesNameClosure const *info = user;
-	/* FIXME : get an 'ID' rather than using index */
-	int ID = e_xml_get_integer_prop_by_name_with_default (series,
-		"index", -1);
-
+	int ID = gup_gnm_series_get_id (series);
 	if (ID != info->seriesID)
 		return FALSE;
 
 	xmlSetProp (series, "name", info->name);
-	guppi_seq_string_set (GUPPI_SEQ_STRING (graph->series.names),
+	guppi_seq_string_set (graph->series.names,
 		info->seriesID, info->name);
 	return TRUE;
 }
@@ -737,7 +717,11 @@ gup_gnm_graph_markup_spec (GupGnmGraph *graph)
 		gup_gnm_graph_clear_names (graph);
 	}
 	/* 0.1) reset the colours to stock */
+
 	guppi_color_palette_set_alien_stock (graph->series.colours);
+#if 0
+	guppi_color_palette_set_stock (graph->series.colours);
+#endif
 
 	/* 0.2) clear out the markers too */
 	g_array_set_size (graph->series.markers, 0);
@@ -760,7 +744,7 @@ gup_gnm_graph_markup_spec (GupGnmGraph *graph)
 		}
 
 		/* 3) Add shiny new descriptors */
-		if (NULL != (descriptor = plot_get_descriptor (plot))) {
+		if (NULL != (descriptor = gup_gnm_plot_get_descriptor (plot))) {
 			int i;
 			xmlNode *dim, *layout = xmlNewChild (plot, plot->ns,
 				"DataLayout", NULL);
@@ -817,7 +801,7 @@ gup_gnm_graph_markup_spec (GupGnmGraph *graph)
 	}
 
 	for (i = 0; i < all_names->len ; i++)
-		guppi_seq_string_append_nc (GUPPI_SEQ_STRING (graph->series.names),
+		guppi_seq_string_append_nc (graph->series.names,
 			g_ptr_array_index (all_names, i));
 
 	g_ptr_array_free (all_names, TRUE);
@@ -857,15 +841,19 @@ gup_gnm_graph_generate_series (GupGnmGraph *graph)
 		xmlFreeNode (data);
 	}
 
-	g_return_if_fail (manager->arrangement_len >= 1);
-	g_return_if_fail (manager->data_ids != NULL);
-	g_return_if_fail (manager->header_ids != NULL);
-
 	gup_gnm_graph_clear_names (graph);
 
-	if (NULL != (descriptor = plot_get_descriptor (plot)))
-		descriptor->arrange_data (graph, plot,
-			xmlNewChild (plot, plot->ns, "Data", NULL));
+	data = xmlNewChild (plot, plot->ns, "Data", NULL);
+	descriptor = gup_gnm_plot_get_descriptor (plot);
+
+	/* There needs to be data and a known descriptor type */
+	if (manager->arrangement_len >= 1 && descriptor != NULL) {
+		g_return_if_fail (manager->data_ids != NULL);
+		g_return_if_fail (manager->header_ids != NULL);
+		g_return_if_fail (descriptor->arrange_data != NULL);
+
+		descriptor->arrange_data (graph, plot, data);
+	}
 
 	gup_gnm_graph_markup_spec (graph);
 }
@@ -937,7 +925,7 @@ GuppiSeqScalar *
 gup_gnm_graph_stock_index  (GupGnmGraph *graph, int const n)
 {
 	int i;
-	GuppiSeqScalar *indicies = GUPPI_SEQ_SCALAR (guppi_seq_scalar_new ());
+	GuppiSeqScalar *indicies = GUPPI_SEQ_SCALAR (guppi_seq_scalar_core_new ());
 	for (i = 0; i < n ; ++i)
 		guppi_seq_scalar_append (indicies, i);
 
@@ -949,7 +937,7 @@ GuppiSeqString *
 gup_gnm_graph_stock_labels (GupGnmGraph *graph, int const n)
 {
 	int i;
-	GuppiSeqString *labels = GUPPI_SEQ_STRING (guppi_seq_string_new ());
+	GuppiSeqString *labels = GUPPI_SEQ_STRING (guppi_seq_string_core_new ());
 	for (i = 0; i < n ; ++i)
 		guppi_seq_string_append_nc (labels, 
 			guppi_strdup_printf ("%d", i));
