@@ -167,6 +167,7 @@ impl_addVector (PortableServer_Servant servant,
 		const GNOME_Gnumeric_VectorSelection subscriber,
 		const GNOME_Gnumeric_VectorType type,
 		const GNOME_Gnumeric_VectorID id,
+		const CORBA_char *default_fmt,
 		CORBA_Environment *ev)
 {
 	GupGnmManager *manager = gup_gnm_manager_from_servant (servant);
@@ -307,7 +308,7 @@ static void
 gup_gnm_manager_print (GnomePrintContext * ctx, double width, double height,
 		       Bonobo_PrintScissor const *scissor, gpointer graph)
 {
-	GuppiRootGroupView *plot = gup_gnm_graph_get_plot (graph);
+	GuppiRootGroupView *plot = gup_gnm_graph_get_view (graph);
 	guppi_element_view_print_to_bbox (GUPPI_ELEMENT_VIEW (plot),
 		ctx, 0, 0, width, height);
 }
