@@ -323,7 +323,7 @@ cb_sample_pressed (GtkWidget *button, GupGnmTypeSelector *typesel)
 		return;
 
 	if (typesel->sample_plot == NULL) {
-		GuppiRootGroupView *plot = gup_gnm_graph_get_plot (typesel->graph);
+		GuppiRootGroupView *plot = gup_gnm_graph_get_view (typesel->graph);
 
 		g_return_if_fail (plot != NULL);
 
