@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-axis-item.c,v 1.36 2001/10/15 20:58:40 trow Exp $ */
+/* $Id: guppi-axis-item.c,v 1.37 2002/01/20 05:21:09 trow Exp $ */
 
 /*
  * guppi-axis-item.c
@@ -322,7 +322,7 @@ render (GuppiCanvasItem *gci, GnomeCanvasBuf *buf)
       g_assert_not_reached ();
     }
 
-    guppi_paint_soft_box (buf, x0, y0, x1, y1, edge_color);
+    guppi_paint_sharp_box (buf, x0, y0, x1, y1, edge_color);
   }
 
   /* Next, paint the legend (if necessary) */
@@ -453,7 +453,7 @@ render (GuppiCanvasItem *gci, GnomeCanvasBuf *buf)
 	    g_assert_not_reached ();
 	  }
 
-	  guppi_paint_soft_box (buf, x0, y0, x1, y1, tick_color);
+	  guppi_paint_sharp_box (buf, x0, y0, x1, y1, tick_color);
 	}
 
 	/* Paint label */
@@ -599,4 +599,4 @@ GtkType guppi_axis_item_get_type (void)
   return guppi_axis_item_type;
 }
 
-/* $Id: guppi-axis-item.c,v 1.36 2001/10/15 20:58:40 trow Exp $ */
+/* $Id: guppi-axis-item.c,v 1.37 2002/01/20 05:21:09 trow Exp $ */
