@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-axis-state.c,v 1.29 2001/11/20 03:41:00 trow Exp $ */
+/* $Id: guppi-axis-state.c,v 1.30 2002/01/14 05:00:55 trow Exp $ */
 
 /*
  * guppi-axis-state.c
@@ -310,6 +310,7 @@ guppi_axis_state_legend_span (GuppiAxisState *state)
 
 double
 guppi_axis_state_maximum_span (GuppiAxisState *state,
+			       double label_scale,
 			       GuppiAxisMarkers *marks)
 {
   gint i;
@@ -318,6 +319,7 @@ guppi_axis_state_maximum_span (GuppiAxisState *state,
   gboolean show_edge, care_about_width, rotate_labels;
 
   g_return_val_if_fail (GUPPI_IS_AXIS_STATE (state), 0);
+  g_return_val_if_fail (label_scale > 0, 0);
   g_return_val_if_fail (GUPPI_IS_AXIS_MARKERS (marks), 0);
 
   guppi_element_state_get (GUPPI_ELEMENT_STATE (state),
@@ -357,9 +359,9 @@ guppi_axis_state_maximum_span (GuppiAxisState *state,
       span += offset;
       if (care_about_width) {
 	if (guppi_tick_label (tick) != NULL)
-	  span += gnome_font_get_width_string (font, guppi_tick_label (tick));
+	  span += label_scale * gnome_font_get_width_string (font, guppi_tick_label (tick));
       } else {
-	span += gnome_font_get_ascender (font) + gnome_font_get_descender (font);
+	span += label_scale * (gnome_font_get_ascender (font) + gnome_font_get_descender (font));
       }
     }
 
@@ -422,20 +424,27 @@ guppi_axis_state_label_shrink_to_fit_factor (GuppiAxisState *state,
 }
 
 void
-guppi_axis_state_get_size (GuppiAxisState *state, GuppiAxisMarkers *am, double *w, double *h)
+guppi_axis_state_get_size (GuppiAxisState *state, 
+			   double text_scale,
+			   GuppiAxisMarkers *am,
+			   double *w, double *h)
 {
   guppi_compass_t pos;
   double span = 0;
 
   g_return_if_fail (GUPPI_IS_AXIS_STATE (state));
 
+  if (text_scale < 1e-8) {
+    text_scale = 1.0;
+  }
+
   guppi_element_state_get (GUPPI_ELEMENT_STATE (state),
 			   "position", &pos,
 			   NULL);
 
   if (am != NULL) {
 
-    span = guppi_axis_state_maximum_span (state, am);
+    span = guppi_axis_state_maximum_span (state, text_scale, am);
 
   }
 
@@ -448,4 +457,4 @@ guppi_axis_state_get_size (GuppiAxisState *state, GuppiAxisMarkers *am, double *
   }
 }
 
-/* $Id: guppi-axis-state.c,v 1.29 2001/11/20 03:41:00 trow Exp $ */
+/* $Id: guppi-axis-state.c,v 1.30 2002/01/14 05:00:55 trow Exp $ */
