@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-axis-state.h,v 1.15 2001/10/11 21:11:12 trow Exp $ */
+/* $Id: guppi-axis-state.h,v 1.16 2002/01/14 05:00:55 trow Exp $ */
 
 /*
  * guppi-axis-state.h
@@ -77,16 +77,16 @@ void guppi_axis_state_tick_properties (GuppiAxisState *,
 gchar *guppi_axis_state_displayed_legend (GuppiAxisState *);
 double guppi_axis_state_legend_span (GuppiAxisState *);
 
-double guppi_axis_state_maximum_span (GuppiAxisState *, GuppiAxisMarkers *);
+double guppi_axis_state_maximum_span (GuppiAxisState *, double label_scale, GuppiAxisMarkers *);
 
 double guppi_axis_state_label_shrink_to_fit_factor (GuppiAxisState *,
 						    GuppiAxisMarkers *,
 						    double span);
 
-void guppi_axis_state_get_size (GuppiAxisState *ax, GuppiAxisMarkers *, double *w, double *h);
+void guppi_axis_state_get_size (GuppiAxisState *ax, double label_scale, GuppiAxisMarkers *, double *w, double *h);
 
 END_GUPPI_DECLS
 
 #endif /* _INC_GUPPI_AXIS_STATE_H */
 
-/* $Id: guppi-axis-state.h,v 1.15 2001/10/11 21:11:12 trow Exp $ */
+/* $Id: guppi-axis-state.h,v 1.16 2002/01/14 05:00:55 trow Exp $ */
