@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-axis-view.c,v 1.14 2001/10/15 20:58:40 trow Exp $ */
+/* $Id: guppi-axis-view.c,v 1.18 2002/01/22 02:01:14 trow Exp $ */
 
 /*
  * guppi-axis-view.c
@@ -53,10 +53,12 @@ compute_size (GuppiElementView *view)
   GuppiElementState *state = guppi_element_view_state (view);
   GuppiAxisMarkers *am;
   guppi_compass_t pos;
-  double w, h;
+  gboolean shrink_to_fit;
+  double w, h, scale = 1.0;
 
   guppi_element_state_get (state,
 			   "position", &pos,
+			   "shrink_labels_to_fit", &shrink_to_fit,
 			   NULL);
 
   if (pos == GUPPI_NORTH || pos == GUPPI_SOUTH) {
@@ -64,7 +66,20 @@ compute_size (GuppiElementView *view)
   } else {
     am = guppi_element_view_axis_markers (view, GUPPI_Y_AXIS);
   }
-  guppi_axis_state_get_size (GUPPI_AXIS_STATE (state), am, &w, &h);
+
+  /* Because of problems with how the layout engine does things, this doesn't
+     quite work right now... changed signals don't play out the way they should,
+     so we seem to end up with truncated labels way too often.  I'm turning this
+     off for now. */
+#if 0
+  if (shrink_to_fit && am) {
+    scale = guppi_axis_view_label_shrink_to_fit_factor (GUPPI_AXIS_VIEW (view), am);
+    if (scale < 1e-8)
+      scale = 1.0;
+  }
+#endif
+
+  guppi_axis_state_get_size (GUPPI_AXIS_STATE (state), scale, am, &w, &h);
 
   guppi_element_view_changed_size (view, w, h);
 }
@@ -89,25 +104,6 @@ changed (GuppiElementView *view)
 
 /**************************************************************************/
 
-static GtkWidget *
-config_cb (gpointer user_data)
-{
-  return gtk_label_new ("Axis View");
-}
-
-static GuppiConfigItem *
-config_tree (GuppiElementView *view)
-{
-  GuppiConfigItem *node;
-
-  node = guppi_config_item_new (_("Axis: Coordinates"),
-				_("Coordinates"), config_cb, view);
-
-  return node;
-}
-
-/**************************************************************************/
-
 static void
 view_init (GuppiElementView *view)
 {
@@ -145,8 +141,6 @@ guppi_axis_view_class_init (GuppiAxisViewClass *klass)
   view_class->canvas_item_type = GUPPI_TYPE_AXIS_ITEM;
   view_class->print_type = GUPPI_TYPE_AXIS_PRINT;
   view_class->view_init = view_init;
-
-  view_class->config_tree = config_tree;
 }
 
 static void
@@ -268,6 +262,9 @@ guppi_axis_view_label_shrink_to_fit_factor (GuppiAxisView *view, GuppiAxisMarker
 
   state = guppi_element_view_state ((GuppiElementView *) view);
 
+  if (! guppi_geometry_positioned (guppi_element_view_geometry ((GuppiElementView *) view)))
+    return 0;
+
   guppi_element_state_get (state,
 			   "position", &pos,
 			   "rotate_labels", &rotate_labels,
@@ -369,14 +366,13 @@ guppi_axis_view_label_shrink_to_fit_factor (GuppiAxisView *view, GuppiAxisMarker
   scale = 1.0;
   i = 1;
   thrash = 0;
-  while (i < N) {
+  while (i < N && thrash < N*N) {
     if (label_pos[i-1] + scale * label_size[i-1]/2 <= label_pos[i] - scale * label_size[i]/2) {
       ++i;
     } else {
       scale = 0.98 * (label_pos[i] - label_pos[i-1]) / (label_size[i-1]/2 + label_size[i]/2);
       i = 1;
       ++thrash;
-      g_assert (thrash < N*N);
     }
   }
 
@@ -386,4 +382,4 @@ guppi_axis_view_label_shrink_to_fit_factor (GuppiAxisView *view, GuppiAxisMarker
   return scale;
 }
 
-/* $Id: guppi-axis-view.c,v 1.14 2001/10/15 20:58:40 trow Exp $ */
+/* $Id: guppi-axis-view.c,v 1.18 2002/01/22 02:01:14 trow Exp $ */
