@@ -1,10 +1,11 @@
 /* This is -*- C -*- */
-/* $Id: guppi-axis-view.h,v 1.4 2001/01/16 23:35:56 trow Exp $ */
+/* $Id: guppi-axis-view.h,v 1.6 2001/10/15 20:58:40 trow Exp $ */
 
 /*
  * guppi-axis-view.h
  *
  * Copyright (C) 2000 EMC Capital Management, Inc.
+ * Copyright (C) 2001 The Free Software Foundation
  *
  * Developed by Jon Trowbridge <trow@gnu.org> and
  * Havoc Pennington <hp@pobox.com>.
@@ -55,8 +56,22 @@ struct _GuppiAxisViewClass {
 
 GtkType guppi_axis_view_get_type (void);
 
+void guppi_axis_view_tick_properties (GuppiAxisView *view,
+				      const GuppiTick *,
+				      double label_scale,
+				      gboolean *show_tick,
+				      guint32 *color,
+				      double *thickness,
+				      double *length,
+				      gboolean *show_label,
+				      double *label_offset,
+				      guint32 *label_color,
+				      GnomeFont **label_font);
+
+double guppi_axis_view_label_shrink_to_fit_factor (GuppiAxisView *, GuppiAxisMarkers *);
+
 END_GUPPI_DECLS
 
 #endif /* _INC_GUPPI_AXIS_VIEW_H */
 
-/* $Id: guppi-axis-view.h,v 1.4 2001/01/16 23:35:56 trow Exp $ */
+/* $Id: guppi-axis-view.h,v 1.6 2001/10/15 20:58:40 trow Exp $ */
