@@ -1,4 +1,4 @@
-/* $Id: init.c,v 1.4 2001/05/06 00:07:26 trow Exp $ */
+/* $Id: init.c,v 1.5 2002/01/14 05:00:57 trow Exp $ */
 
 /*
  * init.c
@@ -25,13 +25,8 @@
  */
 
 #include <config.h>
-#include <guppi-scripting.h>
 #include <guppi-plot-plug-in.h>
 #include "guppi-barchart-state.h"
-#include "guppi-scm-barchart.h"
-#ifdef HAVE_PYTHON
-void guppi_python_barchart_init (void);
-#endif
 
 GuppiPlugIn *guppi_plug_in (void);
 
@@ -53,15 +48,6 @@ guppi_plug_in (void)
   pi->magic_number = GUPPI_PLUG_IN_MAGIC_NUMBER;
   ppi->element_constructor = make_element;
 
-  if (guppi_supports_guile ())
-    guppi_scm_barchart_init ();
-
-#ifdef HAVE_PYTHON
-  if (guppi_supports_python ())
-    guppi_python_barchart_init ();
-#endif
-  /* Do any other necessary initialization here. */
-
   return pi;
 }
 
@@ -69,4 +55,4 @@ guppi_plug_in (void)
 
 
 
-/* $Id: init.c,v 1.4 2001/05/06 00:07:26 trow Exp $ */
+/* $Id: init.c,v 1.5 2002/01/14 05:00:57 trow Exp $ */
