@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-frame-item.c,v 1.9 2001/09/24 20:56:21 trow Exp $ */
+/* $Id: guppi-frame-item.c,v 1.10 2002/01/20 05:21:10 trow Exp $ */
 
 /*
  * guppi-frame-item.c
@@ -54,11 +54,11 @@ update (GuppiCanvasItem *gci, double aff[6], ArtSVP *svp, gint flags)
 
 
 static void
-soft_box (GnomeCanvasBuf *buf,
+sharp_box (GnomeCanvasBuf *buf,
 	  double x, double y,
 	  double n, double s, double w, double e, guint32 color)
 {
-  guppi_paint_soft_box (buf, x - w, y - n, x + e, y + s, color);
+  guppi_paint_sharp_box (buf, x - w, y - n, x + e, y + s, color);
 }
 
 
@@ -239,7 +239,7 @@ render (GuppiCanvasItem *gci, GnomeCanvasBuf *buf)
 	      span_e = cx1 - cx0;
 	  }
 
-	  soft_box (buf, xx, yy, span_n, span_s, span_w, span_e, color);
+	  sharp_box (buf, xx, yy, span_n, span_s, span_w, span_e, color);
 
 	}
 
@@ -363,4 +363,4 @@ guppi_frame_item_new (void)
 
 
 
-/* $Id: guppi-frame-item.c,v 1.9 2001/09/24 20:56:21 trow Exp $ */
+/* $Id: guppi-frame-item.c,v 1.10 2002/01/20 05:21:10 trow Exp $ */
