@@ -1,4 +1,4 @@
-/* $Id: init.c,v 1.5 2001/05/06 00:07:28 trow Exp $ */
+/* $Id: init.c,v 1.6 2002/01/14 05:01:01 trow Exp $ */
 
 /*
  * init.c
@@ -25,13 +25,8 @@
  */
 
 #include <config.h>
-#include <guppi-scripting.h>
 #include <guppi-plot-plug-in.h>
 #include "guppi-legend-state.h"
-#include "guppi-scm-legend.h"
-#ifdef HAVE_PYTHON
-void guppi_python_legend_init (void);
-#endif
 
 GuppiPlugIn *guppi_plug_in (void);
 
@@ -53,14 +48,6 @@ guppi_plug_in (void)
   pi->magic_number = GUPPI_PLUG_IN_MAGIC_NUMBER;
   ppi->element_constructor = make_element;
 
-  if (guppi_supports_guile ())
-    guppi_scm_legend_init ();
-#ifdef HAVE_PYTHON
-  if (guppi_supports_python ())
-    guppi_python_legend_init ();
-#endif
-  /* Do any other necessary initialization here. */
-
   return pi;
 }
 
@@ -68,4 +55,4 @@ guppi_plug_in (void)
 
 
 
-/* $Id: init.c,v 1.5 2001/05/06 00:07:28 trow Exp $ */
+/* $Id: init.c,v 1.6 2002/01/14 05:01:01 trow Exp $ */
