@@ -1,4 +1,4 @@
-/* $Id: init.c,v 1.11 2001/10/12 03:15:09 trow Exp $ */
+/* $Id: init.c,v 1.12 2002/01/14 05:01:05 trow Exp $ */
 
 /*
  * init.c
@@ -26,13 +26,8 @@
  */
 
 #include <config.h>
-#include <guppi-scripting.h>
 #include <guppi-plot-plug-in.h>
 #include "guppi-linegraph-state.h"
-#include "guppi-scm-linegraph.h"
-#ifdef HAVE_PYTHON
-void guppi_python_linegraph_init (void);
-#endif
 
 GuppiPlugIn *guppi_plug_in (void);
 
@@ -56,17 +51,10 @@ guppi_plug_in (void)
   pi->magic_number = GUPPI_PLUG_IN_MAGIC_NUMBER;
   ppi->element_constructor = make_element;
 
-  if (guppi_supports_guile ())
-    guppi_scm_linegraph_init ();
-#ifdef HAVE_PYTHON
-  if (guppi_supports_python ())
-    guppi_python_linegraph_init ();
-#endif
-
   /* Do any other necessary initialization here. */
 
   return pi;
 }
 
 
-/* $Id: init.c,v 1.11 2001/10/12 03:15:09 trow Exp $ */
+/* $Id: init.c,v 1.12 2002/01/14 05:01:05 trow Exp $ */
