@@ -1,4 +1,4 @@
-/* $Id: guppi-scatter-item.c,v 1.32 2001/10/02 04:05:39 trow Exp $ */
+/* $Id: guppi-scatter-item.c,v 1.33 2001/11/08 06:13:40 trow Exp $ */
 
 /*
  * guppi-scatter-item.c
@@ -103,8 +103,8 @@ gather_pairs_cb (GuppiIndexedPair *pair, gsize N, gpointer closure)
 {
   GatherInfo *info = closure;
   GuppiScatterState *state = GUPPI_SCATTER_STATE (guppi_canvas_item_state (info->item));
-  GuppiAlphaTemplate *atemp;
-  double scale, r, g, b, a;
+  GuppiPixbuf *pixbuf;
+  double scale;
   gint x, y;
   gsize i = 0;
   guint32 color;
@@ -113,12 +113,14 @@ gather_pairs_cb (GuppiIndexedPair *pair, gsize N, gpointer closure)
 
   for (i = 0; i < N; ++i) {
     if (guppi_element_view_valid_vp (guppi_canvas_item_view (info->item), pair[i].x, pair[i].y)) {
-      atemp = guppi_scatter_state_get_point_template (state, pair[i].i, scale, &color);
-      if (atemp != NULL) {
+      pixbuf = guppi_scatter_state_get_point_pixbuf (state, pair[i].i, scale, &color);
+      if (pixbuf != NULL) {
 	guppi_canvas_item_vp2c (info->item, pair[i].x, pair[i].y, &x, &y);
-	UINT_TO_RGBA (color, &r, &g, &b, &a);
-	guppi_alpha_template_print (atemp, x, y, r, g, b, a, info->buf);
-	guppi_unref (atemp);
+
+	/* FIXME: hardwired colormap colors */
+	guppi_pixbuf_color_mapped_paste (pixbuf, x, y, color, 0xff0000ff, 0x000000ff, 0xff, info->buf);
+
+	guppi_pixbuf_unref (pixbuf);
       }
     }
   }
@@ -239,4 +241,4 @@ GtkType guppi_scatter_item_get_type (void)
 
 
 
-/* $Id: guppi-scatter-item.c,v 1.32 2001/10/02 04:05:39 trow Exp $ */
+/* $Id: guppi-scatter-item.c,v 1.33 2001/11/08 06:13:40 trow Exp $ */
