@@ -1,4 +1,4 @@
-/* $Id: demo.c,v 1.8 2001/11/16 16:58:46 trow Exp $ */
+/* $Id: demo.c,v 1.10 2002/01/08 06:28:57 trow Exp $ */
 
 /*
  * demo.c
@@ -31,8 +31,10 @@
 #include <glade/glade.h>
 #include "guppi-root-group-view.h"
 #include "guppi-group-view-layout.h"
-#include <guppi-seq-scalar.h>
-#include <guppi-data-table.h>
+
+#include <guppi-seq-scalar-core.h>
+#include <guppi-data-table-core.h>
+
 #include <guppi-memory.h>
 #include <guppi-data-socket.h>
 #include <guppi-useful.h>
@@ -40,6 +42,7 @@
 #include <guppi-plot-init.h>
 #include <guppi-color-palette.h>
 #include <guppi-marker.h>
+#include <guppi-config-dialog.h>
 
 #include <guppi-group-state.h>
 #include <guppi-group-view.h>
@@ -148,7 +151,7 @@ build_gui (void)
 
 /* ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** */
 
-#define DATA_COUNT 500
+#define DATA_COUNT 250
 
 static GuppiElementView *
 build_scatter_demo (void)
@@ -160,8 +163,8 @@ build_scatter_demo (void)
   gint i;
   double t, x, y;
 
-  x_data = GUPPI_SEQ_SCALAR (guppi_seq_scalar_new ());
-  y_data = GUPPI_SEQ_SCALAR (guppi_seq_scalar_new ());
+  x_data = guppi_seq_scalar_core_new ();
+  y_data = guppi_seq_scalar_core_new ();
 
   for (i=0; i<DATA_COUNT; ++i) {
     t = 2*M_PI*i/(double)DATA_COUNT;
@@ -256,7 +259,7 @@ build_barchart_demo (void)
   gint i, j;
   gchar *str;
 
-  table = GUPPI_DATA_TABLE (guppi_data_table_new ());
+  table = guppi_data_table_core_new ();
   guppi_data_table_set_dimensions (table, DATA_ROWS, DATA_COLS);
   for (i = 0; i < DATA_ROWS; ++i) {
 
@@ -344,7 +347,7 @@ build_linechart_demo (void)
   GuppiSeqScalar *seq;
   gint i;
 
-  seq = GUPPI_SEQ_SCALAR (guppi_seq_scalar_new ());
+  seq = guppi_seq_scalar_core_new ();
 
   for (i = 0; i < LINE_SEQ_LEN; ++i)
     guppi_seq_scalar_append (seq, sin (i));
@@ -408,7 +411,7 @@ build_pie_demo (void)
   GuppiColorPalette *pal;
   gint i;
 
-  seq = (GuppiSeqScalar *) guppi_seq_scalar_new ();
+  seq = guppi_seq_scalar_core_new ();
   for (i = 0; i < 10; ++i) {
     guppi_seq_scalar_append (GUPPI_SEQ_SCALAR (seq), i+1);
   }
@@ -542,6 +545,17 @@ layout_elements (void)
   guppi_group_view_layout_center_horizontally (group, text_view);
 
   guppi_group_view_layout_vertically_adjacent (group, text_view, scatter_view, 0); 
+
+  {
+    GuppiConfigModel *model;
+    GtkWidget *w;
+
+    model = guppi_element_view_make_config_model ((GuppiElementView *) root_view);
+    w = guppi_config_dialog_new (model, root_view);
+    guppi_unref (model);
+
+    gtk_widget_show (w);
+  }
 }
 
 int
@@ -558,7 +572,7 @@ main (int argc, char *argv[])
   close (fd);
   
   init (argc, argv);
-
+  
   // guppi_memory_trace (TRUE);
   // guppi_set_verbosity (GUPPI_VERBOSE);
 
@@ -617,4 +631,4 @@ main (int argc, char *argv[])
 
 
 
-/* $Id: demo.c,v 1.8 2001/11/16 16:58:46 trow Exp $ */
+/* $Id: demo.c,v 1.10 2002/01/08 06:28:57 trow Exp $ */
