@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-curve.h,v 1.9 2001/01/16 23:36:12 trow Exp $ */
+/* $Id: guppi-curve.h,v 1.12 2001/11/19 05:40:40 trow Exp $ */
 
 /*
  * guppi-curve.h
@@ -32,7 +32,7 @@
 #include <libart_lgpl/libart.h>
 #include "guppi-data.h"
 
-#include <guppi-defs.h>
+#include  "guppi-defs.h"
 
 BEGIN_GUPPI_DECLS
 
@@ -45,6 +45,35 @@ struct _GuppiCurve {
 
 struct _GuppiCurveClass {
   GuppiDataClass parent_class;
+
+  /* Mandatory functions */
+
+  void (*bounds) (GuppiCurve *, double *, double *);
+  void (*get) (GuppiCurve *, double, double *, double *);
+
+
+  /* Optional functions */
+
+  void (*bbox) (GuppiCurve *, double, double,
+		double *, double *, double *, double *);
+
+  gboolean (*clamp) (GuppiCurve *, double *, double *,
+		     double, double, double, double);
+
+  void (*sample) (GuppiCurve *,
+		  gconstpointer t_vec, gint t_stride, gsize N,
+		  gpointer x_vec, gint x_stride,
+		  gpointer y_vec, gint y_stride);
+  void (*sample_uniformly) (GuppiCurve *,
+			    double t0, double t1, gsize N,
+			    double *x_vec, gint x_stride,
+			    double *y_vec, gint y_stride);
+
+  ArtVpath *(*approx_to_path) (GuppiCurve *, double t0, double t1,
+			       double x_error, double y_error,
+			       double x0, double y0, double x1, double y1,
+			       double scale_x, double scale_y);
+
 };
 
 #define GUPPI_TYPE_CURVE (guppi_curve_get_type())
@@ -63,16 +92,11 @@ double guppi_curve_parameter_upper_bound (GuppiCurve *);
 
 gboolean guppi_curve_parameter_in_bounds (GuppiCurve *, double t);
 double guppi_curve_clamp_parameter (GuppiCurve *, double t);
-double guppi_curve_parameter_01 (GuppiCurve *, double t);
 
 void guppi_curve_get (GuppiCurve *, double t, double *x, double *y);
 double guppi_curve_get_x (GuppiCurve *, double t);
 double guppi_curve_get_y (GuppiCurve *, double t);
 
-void guppi_curve_get_01 (GuppiCurve *, double t, double *x, double *y);
-double guppi_curve_get_x_01 (GuppiCurve *, double t);
-double guppi_curve_get_y_01 (GuppiCurve *, double t);
-
 /* Find a bounding box containing the portion of the curve parameterized
    by [t0, t1]. */
 void guppi_curve_get_bbox (GuppiCurve *, double t0, double t1,
@@ -98,11 +122,13 @@ void guppi_curve_sample_uniformly_to_path (GuppiCurve *,
 
 ArtVpath *guppi_curve_approximate_to_path (GuppiCurve *,
 					   double t0, double t1,
-					   double x_error, double y_error);
+					   double x_error, double y_error,
+					   double x0, double y0, double x1, double y1,
+					   double scale_x, double scale_y);
 
 
 END_GUPPI_DECLS
 
 #endif /* _INC_GUPPI_CURVE_H */
 
-/* $Id: guppi-curve.h,v 1.9 2001/01/16 23:36:12 trow Exp $ */
+/* $Id: guppi-curve.h,v 1.12 2001/11/19 05:40:40 trow Exp $ */
