@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-data-tree.c,v 1.18 2001/10/10 06:48:08 trow Exp $ */
+/* $Id: guppi-data-tree.c,v 1.20 2002/01/15 04:13:39 trow Exp $ */
 
 /*
  * guppi-data-tree.c
@@ -33,8 +33,6 @@
 #include <gtk/gtksignal.h>
 
 #include <guppi-convenient.h>
-#include <guppi-exit.h>
-
 
 /*
   There are a whole bunch of private functions for manipulating
@@ -591,8 +589,6 @@ guppi_data_tree_main (void)
 
   if (tree == NULL) {
     tree = guppi_data_tree_new ();
-    guppi_exit_connect_shutdown_func (guppi_unref_fn, tree,
-				      "Free Main Data Tree");
   }
 
   return tree;
@@ -623,4 +619,4 @@ guppi_data_tree_spew (const GuppiDataTree * tree)
 
 
 
-/* $Id: guppi-data-tree.c,v 1.18 2001/10/10 06:48:08 trow Exp $ */
+/* $Id: guppi-data-tree.c,v 1.20 2002/01/15 04:13:39 trow Exp $ */
