@@ -29,7 +29,7 @@
 #define _INC_GUPPI_DATE_INDEXED_H
 
 /* #include <gtk/gtk.h> */
-#include <guppi-defs.h>
+#include  "guppi-defs.h"
 #include "guppi-data.h"
 
 BEGIN_GUPPI_DECLS
@@ -45,9 +45,14 @@ struct _GuppiDateIndexed {
 struct _GuppiDateIndexedClass {
   GuppiDataClass parent_class;
 
-  xmlNodePtr (*export_xml_element) (GuppiDateIndexed *, const GDate *, GuppiXMLDocument *);
-  void (*import_xml_element) (GuppiDateIndexed *, const GDate *, GuppiXMLDocument *, xmlNodePtr);
+  void     (*bounds)      (GuppiDateIndexed *di, GDate *start, GDate *end);
+  gboolean (*valid)       (GuppiDateIndexed *di, const GDate *dt);
+  gboolean (*step)        (GuppiDateIndexed *di, const GDate *orig, gint delta, GDate *modified);
+  gint     (*size)        (GuppiDateIndexed *di);
+  void     (*bounds_hint) (GuppiDateIndexed *di, const GDate *start, const GDate *end);
 
+  xmlNodePtr (*export_xml_element) (GuppiDateIndexed *, const GDate *, GuppiXMLDocument *);
+  gboolean   (*import_xml_element) (GuppiDateIndexed *, const GDate *, GuppiXMLDocument *, xmlNodePtr);
 };
 
 #define GUPPI_TYPE_DATE_INDEXED (guppi_date_indexed_get_type ())
@@ -82,4 +87,4 @@ END_GUPPI_DECLS
 
 #endif /* _INC_GUPPI_DATE_INDEXED_H */
 
-/* $Id: guppi-date-indexed.h,v 1.6 2001/05/03 23:03:00 trow Exp $ */
+/* $Id: guppi-date-indexed.h,v 1.8 2001/11/19 05:40:40 trow Exp $ */
