@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-seq-date.c,v 1.15 2001/10/10 06:48:08 trow Exp $ */
+/* $Id: guppi-seq-date.c,v 1.16 2002/01/08 06:28:58 trow Exp $ */
 
 /*
  * guppi-seq-date.c
@@ -149,12 +149,6 @@ op_insert (GuppiData *d, GuppiDataOp *op)
 
 /* ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** */
 
-GuppiData *
-guppi_seq_date_new (void)
-{
-  return guppi_data_new ("GuppiSeqDateCore");
-}
-
 GDate *
 guppi_seq_date_get (GuppiSeqDate *seq, gint i)
 {
@@ -336,4 +330,4 @@ gint guppi_seq_date_lookup (GuppiSeqDate *seq, GDate *dt)
 }
 
 
-/* $Id: guppi-seq-date.c,v 1.15 2001/10/10 06:48:08 trow Exp $ */
+/* $Id: guppi-seq-date.c,v 1.16 2002/01/08 06:28:58 trow Exp $ */
