@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-struct.h,v 1.9 2001/01/16 23:36:22 trow Exp $ */
+/* $Id: guppi-struct.h,v 1.11 2001/11/19 05:40:40 trow Exp $ */
 
 /*
  * guppi-struct.h
@@ -32,19 +32,27 @@
 
 #include "guppi-data.h"
 
-#include <guppi-defs.h>
+#include  "guppi-defs.h"
 
 BEGIN_GUPPI_DECLS 
 
 typedef struct _GuppiStruct GuppiStruct;
 typedef struct _GuppiStructClass GuppiStructClass;
 
+typedef void (*GuppiStructFn) (const gchar *name, GuppiData *data, gpointer closure);
+
 struct _GuppiStruct {
   GuppiData parent;
 };
 
 struct _GuppiStructClass {
   GuppiDataClass parent_class;
+
+  gboolean   (*add_field)  (GuppiStruct *, const gchar *, GtkType);
+  GtkType    (*field_type) (GuppiStruct *, const gchar *);
+  GuppiData *(*get)        (GuppiStruct *, const gchar *);
+  gboolean   (*set)        (GuppiStruct *, const gchar *, GuppiData *);
+  void       (*foreach)    (GuppiStruct *, GuppiStructFn, gpointer);
 };
 
 #define GUPPI_TYPE_STRUCT (guppi_struct_get_type())
@@ -57,12 +65,7 @@ struct _GuppiStructClass {
 
 GtkType guppi_struct_get_type (void);
 
-GuppiData *guppi_struct_new (void);
-
 GtkType guppi_struct_get_field_type (const GuppiStruct *, const gchar *);
-gchar **guppi_struct_get_field_names (const GuppiStruct *);
-
-gsize guppi_struct_size (const GuppiStruct *);
 
 GuppiData *guppi_struct_get (const GuppiStruct *, const gchar *);
 void guppi_struct_set (GuppiStruct *, const gchar *, GuppiData *);
@@ -80,4 +83,4 @@ END_GUPPI_DECLS
 
 #endif /* _INC_GUPPI_STRUCT_H */
 
-/* $Id: guppi-struct.h,v 1.9 2001/01/16 23:36:22 trow Exp $ */
+/* $Id: guppi-struct.h,v 1.11 2001/11/19 05:40:40 trow Exp $ */
