@@ -1,10 +1,11 @@
 /* This is -*- C -*- */
-/* $Id: guppi-alpha-template.c,v 1.21 2001/05/06 08:26:42 trow Exp $ */
+/* $Id: guppi-alpha-template.c,v 1.27 2001/11/19 05:40:44 trow Exp $ */
 
 /*
  * guppi-alpha-template.c
  *
  * Copyright (C) 2000 EMC Capital Management, Inc.
+ * Copyright (C) 2001 The Free Software Foundation
  *
  * Developed by Jon Trowbridge <trow@gnu.org> and
  * Havoc Pennington <hp@pobox.com>.
@@ -26,6 +27,8 @@
  */
 
 #include <config.h>
+#include "guppi-alpha-template.h"
+
 #include <math.h>
 
 #include <libgnomeui/gnome-canvas.h>
@@ -33,45 +36,14 @@
 
 #include <guppi-convenient.h>
 #include <guppi-useful.h>
-#include "guppi-alpha-template.h"
+
 
 #include <libart_lgpl/libart.h>
 
 static GtkObjectClass *parent_class = NULL;
 
-enum {
-  ARG_0
-};
-
 static void
-guppi_alpha_template_get_arg (GtkObject * obj, GtkArg * arg, guint arg_id)
-{
-  switch (arg_id) {
-
-  default:
-    break;
-  };
-}
-
-static void
-guppi_alpha_template_set_arg (GtkObject * obj, GtkArg * arg, guint arg_id)
-{
-  switch (arg_id) {
-
-  default:
-    break;
-  };
-}
-
-static void
-guppi_alpha_template_destroy (GtkObject * obj)
-{
-  if (parent_class->destroy)
-    parent_class->destroy (obj);
-}
-
-static void
-guppi_alpha_template_finalize (GtkObject * obj)
+guppi_alpha_template_finalize (GtkObject *obj)
 {
   GuppiAlphaTemplate *atemp = GUPPI_ALPHA_TEMPLATE (obj);
 
@@ -87,21 +59,18 @@ guppi_alpha_template_finalize (GtkObject * obj)
 }
 
 static void
-guppi_alpha_template_class_init (GuppiAlphaTemplateClass * klass)
+guppi_alpha_template_class_init (GuppiAlphaTemplateClass *klass)
 {
   GtkObjectClass *object_class = (GtkObjectClass *) klass;
 
   parent_class = gtk_type_class (GTK_TYPE_OBJECT);
 
-  object_class->get_arg = guppi_alpha_template_get_arg;
-  object_class->set_arg = guppi_alpha_template_set_arg;
-  object_class->destroy = guppi_alpha_template_destroy;
   object_class->finalize = guppi_alpha_template_finalize;
 
 }
 
 static void
-guppi_alpha_template_init (GuppiAlphaTemplate * obj)
+guppi_alpha_template_init (GuppiAlphaTemplate *obj)
 {
 
 }
@@ -132,8 +101,7 @@ guppi_alpha_template_new (gint w, gint h)
   g_return_val_if_fail (w > 0, NULL);
   g_return_val_if_fail (h > 0, NULL);
 
-  atemp =
-    GUPPI_ALPHA_TEMPLATE (guppi_type_new (guppi_alpha_template_get_type ()));
+  atemp = GUPPI_ALPHA_TEMPLATE (guppi_type_new (guppi_alpha_template_get_type ()));
 
   atemp->width = w;
   atemp->height = h;
@@ -142,7 +110,7 @@ guppi_alpha_template_new (gint w, gint h)
   return atemp;
 }
 
-guchar guppi_alpha_template_get (GuppiAlphaTemplate * atemp, gint x, gint y)
+guchar guppi_alpha_template_get (GuppiAlphaTemplate *atemp, gint x, gint y)
 {
   g_return_val_if_fail (atemp != NULL, '\0');
   g_return_val_if_fail (x >= 0 && x < atemp->width, '\0');
@@ -152,7 +120,7 @@ guchar guppi_alpha_template_get (GuppiAlphaTemplate * atemp, gint x, gint y)
 }
 
 void
-guppi_alpha_template_set (GuppiAlphaTemplate * atemp, gint x, gint y,
+guppi_alpha_template_set (GuppiAlphaTemplate *atemp, gint x, gint y,
 			  guchar a)
 {
   g_return_if_fail (atemp != NULL);
@@ -163,7 +131,7 @@ guppi_alpha_template_set (GuppiAlphaTemplate * atemp, gint x, gint y,
 }
 
 GuppiAlphaTemplate *
-guppi_alpha_template_copy_rectangle (GuppiAlphaTemplate * atemp,
+guppi_alpha_template_copy_rectangle (GuppiAlphaTemplate *atemp,
 				     gint x, gint y, gint w, gint h)
 {
   GuppiAlphaTemplate *acopy;
@@ -197,7 +165,7 @@ guppi_alpha_template_copy_rectangle (GuppiAlphaTemplate * atemp,
 }
 
 void
-guppi_alpha_template_auto_crop (GuppiAlphaTemplate * atemp)
+guppi_alpha_template_auto_crop (GuppiAlphaTemplate *atemp)
 {
   GuppiAlphaTemplate *acopy;
   gint x0, y0, x1, y1, i, j;
@@ -216,6 +184,7 @@ guppi_alpha_template_auto_crop (GuppiAlphaTemplate * atemp)
     }
   }
   --x0;
+  atemp->x_base_point -= x0;
 
   empty_line = TRUE;
   for (x1 = atemp->width - 1; x1 >= x0 && empty_line; --x1) {
@@ -234,6 +203,8 @@ guppi_alpha_template_auto_crop (GuppiAlphaTemplate * atemp)
     }
   }
   --y0;
+  atemp->y_base_point -= y0;
+
 
   empty_line = TRUE;
   for (y1 = atemp->height - 1; y1 >= y0 && empty_line; --y1) {
@@ -261,10 +232,10 @@ guppi_alpha_template_auto_crop (GuppiAlphaTemplate * atemp)
 }
 
 void
-guppi_alpha_template_print (GuppiAlphaTemplate * atemp,
+guppi_alpha_template_print (GuppiAlphaTemplate *atemp,
 			    gint x, gint y,
 			    guint rnow, guint gnow, guint bnow, guint anow,
-			    GnomeCanvasBuf * buf)
+			    GnomeCanvasBuf *buf)
 {
   gint w, h;
 
@@ -287,8 +258,8 @@ guppi_alpha_template_print (GuppiAlphaTemplate * atemp,
   x -= buf->rect.x0;
   y -= buf->rect.y0;
 
-  x += atemp->x_offset;
-  y += atemp->y_offset;
+  x -= atemp->x_base_point;
+  y -= atemp->y_base_point;
 
   if (x + atemp->width >= 0 && x < w && y + atemp->height >= 0 && y < h) {
 
@@ -324,6 +295,75 @@ guppi_alpha_template_print (GuppiAlphaTemplate * atemp,
   }
 }
 
+void
+guppi_alpha_template_gradient_print (GuppiAlphaTemplate *atemp,
+				     gint x, gint y,
+				     guint rgba1, guint rgba2,
+				     guppi_compass_t start,
+				     GnomeCanvasBuf *buf)
+{
+  gint w, h;
+  guint c, rnow, gnow, bnow, anow;
+  double t;
+
+  /* Trying to print the NULL alpha template is just a no-op */
+  if (atemp == NULL)
+    return;
+
+  g_return_if_fail (buf != NULL);
+
+  /* We use the funny variable names (and the declarations inside the if()
+     block rather than at the top) so that this chunk of code can be pasted
+     into guppi_scatter_style_paint() w/o changes. */
+
+  w = buf->rect.x1 - buf->rect.x0;
+  h = buf->rect.y1 - buf->rect.y0;
+
+  x -= buf->rect.x0;
+  y -= buf->rect.y0;
+
+  x -= atemp->x_base_point;
+  y -= atemp->y_base_point;
+
+  if (x + atemp->width >= 0 && x < w && y + atemp->height >= 0 && y < h) {
+
+    gint atpr_x0, atpr_y0, atpr_x1, atpr_y1;
+    gint atpr_i, atpr_j;
+    guchar *atpr_ap;
+    guchar *atpr_arun;
+    guchar *atpr_rgbp;
+    gchar *atpr_rgbrun;
+
+    /* Clip to our viewing area */
+    atpr_x0 = MAX (x, 0);
+    atpr_y0 = MAX (y, 0);
+    atpr_x1 = MIN (x + atemp->width - 1, w - 1);
+    atpr_y1 = MIN (y + atemp->height - 1, h - 1);
+
+    atpr_ap = atemp->data + atemp->width * (atpr_y0 - y) + (atpr_x0 - x);
+    atpr_rgbp = buf->buf + buf->buf_rowstride * atpr_y0 + 3 * atpr_x0;
+    for (atpr_j = atpr_y0; atpr_j <= atpr_y1; ++atpr_j) {
+      atpr_arun = atpr_ap;
+      atpr_rgbrun = atpr_rgbp;
+
+      t = (atpr_j-y) / (double) (atemp->height-1);
+      c = UINT_INTERPOLATE (rgba1, rgba2, t);
+      UINT_TO_RGBA (c, &rnow, &gnow, &bnow, &anow);
+
+      for (atpr_i = atpr_x0; atpr_i <= atpr_x1; ++atpr_i) {
+	if (*atpr_arun > 0) {
+	  PIXEL_RGBA (atpr_rgbrun, rnow, gnow, bnow,
+		      ((1 + anow) * (1 + *atpr_arun)) >> 8);
+	}
+	++atpr_arun;
+	atpr_rgbrun += 3;
+      }
+      atpr_ap += atemp->width;
+      atpr_rgbp += buf->buf_rowstride;
+    }
+  }
+}
+
 /**************************************************************************/
 
 GuppiAlphaTemplate *
@@ -393,6 +433,8 @@ guppi_alpha_template_new_circle (double radius)
   rt1 = (radius + M_SQRT2) * (radius + M_SQRT2);
 
   atemp = guppi_alpha_template_new (span, span);
+  atemp->x_base_point = span / 2;
+  atemp->y_base_point = span / 2;
 
   for (i = 0; i <= span / 2; ++i) {
     for (j = i; j <= span / 2; ++j) {
@@ -460,7 +502,10 @@ guppi_alpha_template_new_ring (double radius, double width)
     rt0 = (radius - width / 2 - M_SQRT2) * (radius - width / 2 - M_SQRT2);
   }
   rt1 = (radius + width / 2 + M_SQRT2) * (radius + width / 2 + M_SQRT2);
+
   atemp = guppi_alpha_template_new (span, span);
+  atemp->x_base_point = span / 2;
+  atemp->y_base_point = span / 2;
 
   for (i = 0; i <= span / 2; ++i) {
     for (j = i; j <= span / 2; ++j) {
@@ -539,6 +584,8 @@ guppi_alpha_template_new_cross (double radius, double width, double theta)
     symmetry = TRUE;
 
   atemp = guppi_alpha_template_new (span, span);
+  atemp->x_base_point = span / 2;
+  atemp->y_base_point = span / 2;
 
   top = symmetry ? span / 2 : span - 1;
 
@@ -604,6 +651,8 @@ guppi_alpha_template_new_ast (double radius, double width, double theta)
   ww = width * width / 4;
 
   atemp = guppi_alpha_template_new (span, span);
+  atemp->x_base_point = span / 2;
+  atemp->y_base_point = span / 2;
 
   top = symmetry ? span / 2 : span - 1;
 
@@ -678,6 +727,8 @@ guppi_alpha_template_new_rectangle (double radius, double width, double theta)
     symmetry = TRUE;
 
   atemp = guppi_alpha_template_new (span, span);
+  atemp->x_base_point = span / 2;
+  atemp->y_base_point = span / 2;
 
   top = symmetry ? span / 2 : span - 1;
 
@@ -745,6 +796,8 @@ guppi_alpha_template_new_box (double radius, double theta)
     symmetry = TRUE;
 
   atemp = guppi_alpha_template_new (span, span);
+  atemp->x_base_point = span / 2;
+  atemp->y_base_point = span / 2;
 
   top = symmetry ? span / 2 : span - 1;
 
@@ -783,252 +836,214 @@ guppi_alpha_template_new_box (double radius, double theta)
   return atemp;
 }
 
-/**************************************************************************/
-
-/*
- * This stuff was needed when the good parts of GnomeFont weren't exposed
- * by gnome-print.
- */
-
-#ifdef USING_OLD_FONT_API
-/*** unexposed gnome-print stuff */
-
-typedef struct {
-  int ch;
-  ArtBpath *bpath;
-  ArtDRect bbox;
-  double wx;
-} Gt1GlyphOutline;
-
-typedef int Gt1NameId;
-
-typedef struct {
-  gpointer psc;
-  gpointer fi;
-  gpointer mfi;
-  gpointer fontdict;
-  Gt1NameId *encoding;
-  Gt1NameId id_charstrings;
-  GHashTable *glyph_outlines;
-} Gt1LoadedFont;
-
-
-Gt1LoadedFont *gt1_load_font (const char *filename);
-void gt1_unload_font (Gt1LoadedFont *);
-
-Gt1GlyphOutline *gt1_glyph_outline_lookup (Gt1LoadedFont *, int glyphnum);
-ArtBpath *gt1_get_glyph_outline (Gt1LoadedFont * font, int glyphnum,
-				 double *p_wx);
-
-
-/* Copied from gnome-print */
-static void
-my_art_drect_bpath (ArtDRect * bbox, const ArtBpath * bpath)
-{
-  /* This implementation is a hack. The real thing needs to go
-     into libart. */
-  ArtVpath *vpath;
-
-  vpath = art_bez_path_to_vec (bpath, 0.25);
-  art_vpath_bbox_drect (vpath, bbox);
-  art_free (vpath);
-}
-
-static Gt1GlyphOutline *
-my_gt1_glyph_outline_lookup (Gt1LoadedFont * font, int c)
-{
-  static GHashTable *outline_hash = NULL;
-  GHashTable *font_hash;
-  Gt1GlyphOutline *go;
-
-  /*
-     To support older versions of gnome-print, we don't use the
-     glyph_outlines hash inside of the Gt1LoadedFont struct.
-
-     Instead, we define a hash for each font, keyed off of the address of
-     the font structure.  (So if we have many copies of the same font,
-     we will get redundant glyph outlines.  Yet another reason not to have
-     many copies of the same font...)
-   */
-
-  if (outline_hash == NULL)
-    outline_hash = g_hash_table_new (NULL, NULL);
-
-  font_hash = g_hash_table_lookup (outline_hash, font);
-  if (font_hash == NULL) {
-    font_hash = g_hash_table_new (NULL, NULL);
-    g_hash_table_insert (outline_hash, font, font_hash);
-  }
-
-  go = (Gt1GlyphOutline *) g_hash_table_lookup (font_hash,
-						GINT_TO_POINTER (c));
-  if (go == NULL) {
-
-    go = guppi_new (Gt1GlyphOutline, 1);
-    go->ch = c;
-    go->bpath = gt1_get_glyph_outline (font, c, &go->wx);
-    my_art_drect_bpath (&go->bbox, go->bpath);
-
-    g_hash_table_insert (font_hash, GINT_TO_POINTER (c), go);
-
-  }
-
-  return go;
-}
-
-static Gt1LoadedFont *
-get_gt1_font (GnomeFont * font)
-{
-  static GHashTable *gt1_hash = NULL;
-  Gt1LoadedFont *gt1_font;
-
-  g_return_val_if_fail (font != NULL, NULL);
-
-  if (gt1_hash == NULL)
-    gt1_hash = g_hash_table_new (g_str_hash, g_str_equal);
-
-  gt1_font = (Gt1LoadedFont *) g_hash_table_lookup (gt1_hash,
-						    font->fontmap_entry->
-						    pfb_fn);
-
-  if (gt1_font == NULL) {
-
-    gt1_font = gt1_load_font (font->fontmap_entry->pfb_fn);
-
-    g_hash_table_insert (gt1_hash,
-			 font->fontmap_entry->pfb_fn, (gpointer) gt1_font);
-
-  }
-
-  return gt1_font;
-}
-
-/* The old, hacky version */
-
 GuppiAlphaTemplate *
-guppi_alpha_template_text_general (GnomeFont * font, double scale,
-				   const gchar * text,
-				   double angle,
-				   gboolean filled, double outline_width)
+guppi_alpha_template_new_triangle (double radius, double width, double theta)
 {
-  Gt1LoadedFont *gt1_font;
-  Gt1GlyphOutline *glyph;
-  gint w, h;
-  ArtIRect bbox, wbi;
-  ArtDRect w_bbox;
-  double affine[6];
-  double rot[6];
-  GnomeCanvasBuf *buf;
   GuppiAlphaTemplate *atemp;
-  guchar *p;
-  ArtBpath *bpath;
-  ArtVpath *vpath;
-  ArtSVP *svp;
-  gint i, j;
-  double size;
+  const gint slice = 3;
+  const double side = 1.0 / slice;
+  gint span = (gint) ceil (2 * radius + width + 1);
+  double cent = span / 2.0;
+  gint i, j, ii, jj, count, val;
+  double ip, jp;
+  double x0, y0, x1, y1, x2, y2, d, r, RR;
 
-  g_return_val_if_fail (font != NULL, NULL);
-  g_return_val_if_fail (scale > 0, NULL);
+  x0 =  radius * cos (M_PI/2 + theta);
+  y0 = -radius * sin (M_PI/2 + theta);
 
-  if (text == NULL || !text[0])
-    return NULL;
+  x1 = radius * cos (M_PI/2 + 2*M_PI/3 + theta);
+  y1 = -radius * sin (M_PI/2 + 2*M_PI/3 + theta);
+  
+  x2 = radius * cos (M_PI/2 + 4*M_PI/3 + theta);
+  y2 = -radius * sin (M_PI/2 + 4*M_PI/3 + theta);
 
-  gt1_font = get_gt1_font (font);
-  g_return_val_if_fail (gt1_font != NULL, NULL);
+  RR = (radius + width) * (radius + width);
 
-  size = guppi_pt2px (font->size * scale);
+  atemp = guppi_alpha_template_new (span, span);
+  atemp->x_base_point = span / 2;
+  atemp->y_base_point = span / 2;
+    
+  for (i = 0; i < span; ++i) {
+    for (j = 0; j < span; ++j) {
 
-  /* First, compute bounding box for the text */
+      count = 0;
 
-  art_affine_scale (affine, size * 0.001, size * -0.001);
-  art_affine_rotate (rot, angle);
-  art_affine_multiply (affine, affine, rot);
+      for (ii = 0; ii < slice; ++ii) {
+	for (jj = 0; jj < slice; ++jj) {
+	  ip = i + (ii + 0.5) * side - cent;
+	  jp = j + (jj + 0.5) * side - cent;
 
-  for (i = 0; text[i]; ++i) {
-    glyph = my_gt1_glyph_outline_lookup (gt1_font, text[i]);
-    art_drect_affine_transform (&w_bbox, &glyph->bbox, affine);
-    art_drect_to_irect (&wbi, &w_bbox);
-    if (i == 0)
-      bbox = wbi;
-    else
-      art_irect_union (&bbox, &bbox, &wbi);
-    affine[4] += glyph->wx * affine[0];
-    affine[5] += glyph->wx * affine[1];
-  }
+	  r = ip * ip + jp * jp;
 
-  w = bbox.x1 - bbox.x0;
-  h = bbox.y1 - bbox.y0;
+	  if (r < RR) {
 
-  /* Next, create a buffer to render the text into */
-  buf = guppi_new0 (GnomeCanvasBuf, 1);
-  buf->buf = guppi_new0 (guchar, w * h * 3);
-  buf->buf_rowstride = w * 3;
-  buf->rect = bbox;
-  buf->bg_color = 0;
-  buf->is_bg = TRUE;
-  buf->is_buf = FALSE;
+	    d = distsq_to_segment (ip, jp, x0, y0, x1, y1);
+	    if (d > width / 2)
+	      d = distsq_to_segment (ip, jp, x1, y1, x2, y2);
+	    if (d > width / 2)
+	      d = distsq_to_segment (ip, jp, x0, y0, x2, y2);
+	    
+	    if (d <= width / 2)
+	      ++count;
 
-  /* Punch the text info our buffer */
+	  }
 
-  art_affine_scale (affine, size * 0.001, size * -0.001);
-  art_affine_rotate (rot, angle);
-  art_affine_multiply (affine, affine, rot);
+	}
+      }
 
-  if (outline_width < 0.5)
-    outline_width = 0.5;
-
-  for (i = 0; text[i]; ++i) {
-
-    glyph = my_gt1_glyph_outline_lookup (gt1_font, text[i]);
-    bpath = art_bpath_affine_transform (glyph->bpath, affine);
-    vpath = art_bez_path_to_vec (bpath, 0.25);
-    art_free (bpath);
-
-    if (filled) {
-      svp = art_svp_from_vpath (vpath);
-    } else {
-      svp = art_svp_vpath_stroke (vpath,
-				  gnome_canvas_join_gdk_to_art
-				  (GDK_JOIN_MITER),
-				  gnome_canvas_cap_gdk_to_art (GDK_CAP_BUTT),
-				  outline_width, 4, 0.25);
-    }
-
-    gnome_canvas_render_svp (buf, svp, 0xffffffff);
-    art_svp_free (svp);
-
-    art_free (vpath);
-
-    affine[4] += glyph->wx * affine[0];
-    affine[5] += glyph->wx * affine[1];
-  }
-
-  /* Copy our buffer into an alpha template object */
-  atemp = guppi_alpha_template_new (w, h);
-  p = buf->buf;
-  for (j = 0; j < h; ++j) {
-    for (i = 0; i < w; ++i) {
-      guppi_alpha_template_set_unsafe (atemp, i, j, *p);
-      p += 3;
+      val = count * 0xff / (slice * slice);
+      guppi_alpha_template_set_unsafe (atemp, i, j, val);
     }
   }
 
-  /* Free our buffer */
-  guppi_free (buf->buf);
-  guppi_free (buf);
+  guppi_alpha_template_auto_crop (atemp);
 
   return atemp;
 }
 
-/**************************************************************************/
+static gint
+half_plane (double x, double y,
+	    double x0, double y0, double x1, double y1)
+{
+  const double epsilon = 1e-8;
 
-#else
+  double dx = x1 - x0;
+  double dy = y1 - y0;
+  double t = - (x - x0) * dy + (y - y0) * dx;
 
-/* The up-to-date version */
+  if (t > epsilon)
+    return +1;
+  if (t < -epsilon)
+    return -1;
+  return 0;
+}
 
 GuppiAlphaTemplate *
-guppi_alpha_template_text_general (GnomeFont * font, double scale,
-				   const gchar * text,
+guppi_alpha_template_new_filled_triangle (double radius, double theta)
+{
+  GuppiAlphaTemplate *atemp;
+  const gint slice = 3;
+  const double side = 1.0 / slice;
+  gint span = (gint) ceil (2 * radius + 1);
+  double cent = span / 2.0;
+  gint i, j, ii, jj, count, val;
+  double ip, jp;
+  double x0, y0, x1, y1, x2, y2, r, R_lower, R_upper;
+
+  x0 =  radius * cos (M_PI/2 + theta);
+  y0 = -radius * sin (M_PI/2 + theta);
+
+  x1 = radius * cos (M_PI/2 + 2*M_PI/3 + theta);
+  y1 = -radius * sin (M_PI/2 + 2*M_PI/3 + theta);
+  
+  x2 = radius * cos (M_PI/2 + 4*M_PI/3 + theta);
+  y2 = -radius * sin (M_PI/2 + 4*M_PI/3 + theta);
+
+  R_lower = radius * radius / 4;
+  R_upper = (radius + 1) * (radius + 1);
+
+  atemp = guppi_alpha_template_new (span, span);
+  atemp->x_base_point = span / 2;
+  atemp->y_base_point = span / 2;
+    
+  for (i = 0; i < span; ++i) {
+    for (j = 0; j < span; ++j) {
+
+      count = 0;
+
+      for (ii = 0; ii < slice; ++ii) {
+	for (jj = 0; jj < slice; ++jj) {
+	  ip = i + (ii + 0.5) * side - cent;
+	  jp = j + (jj + 0.5) * side - cent;
+
+	  r = ip * ip + jp * jp;
+
+	  if (r < R_lower) {
+	    ++count;
+	  } else if (r < R_upper) {
+
+	    if (half_plane (ip, jp, x0, y0, x1, y1) <= 0
+		&& half_plane (ip, jp, x1, y1, x2, y2) <= 0
+		&& half_plane (ip, jp, x2, y2, x0, y0) <= 0)
+	      ++count;
+
+	  }
+
+	}
+      }
+
+      val = count * 0xff / (slice * slice);
+      guppi_alpha_template_set_unsafe (atemp, i, j, val);
+    }
+  }
+
+  guppi_alpha_template_auto_crop (atemp);
+
+  return atemp;
+}
+
+
+GuppiAlphaTemplate *
+guppi_alpha_template_new_bar (double r_forward, double r_back, double width, double theta)
+{
+  GuppiAlphaTemplate *atemp;
+  const gint slice = 3;
+  const double side = 1.0 / slice;
+  double r_max = MAX (r_forward, r_back);
+  gint span = (gint) ceil (2 * r_max + width + 1);
+  double cent = span / 2;
+  gint i, j, ii, jj, count, val;
+  double ip, jp, x0, y0, x1, y1;
+  double r, RR, d;
+
+  x0 = r_forward * cos (theta);
+  y0 = r_forward * sin (theta);
+  
+  x1 = -r_back * cos (theta);
+  y1 = -r_back * sin (theta);
+
+  RR = (r_max + width) * (r_max + width);
+
+  atemp = guppi_alpha_template_new (span, span);
+  atemp->x_base_point = span / 2;
+  atemp->y_base_point = span / 2;
+
+  for (i = 0; i < span; ++i) {
+    for (j = 0; j < span; ++j) {
+
+      count = 0;
+
+      for (ii = 0; ii < slice; ++ii) {
+	for (jj = 0; jj < slice; ++jj) {
+	  ip = i + (ii + 0.5) * side - cent;
+	  jp = j + (jj + 0.5) * side - cent;
+
+	  r = ip * ip + jp * jp;
+
+	  if (r < RR) {
+	    d = distsq_to_segment (ip, jp, x0, y0, x1, y1);
+	    if (d <= width / 2)
+	      ++count;
+	  }
+	}
+      }
+
+      val = count * 0xff / (slice * slice);
+      guppi_alpha_template_set_unsafe (atemp, i, j, val);
+    }
+  }
+
+  guppi_alpha_template_auto_crop (atemp);
+
+  return atemp;
+}
+
+
+/**************************************************************************/
+
+GuppiAlphaTemplate *
+guppi_alpha_template_text_general (GnomeFont *font, double scale,
+				   const gchar *text,
 				   double angle,
 				   gboolean filled, double outline_width)
 {
@@ -1151,9 +1166,4 @@ guppi_alpha_template_text_general (GnomeFont * font, double scale,
   return atemp;
 }
 
-#endif
-
-
-
-
-/* $Id: guppi-alpha-template.c,v 1.21 2001/05/06 08:26:42 trow Exp $ */
+/* $Id: guppi-alpha-template.c,v 1.27 2001/11/19 05:40:44 trow Exp $ */
