@@ -1,6 +1,6 @@
 
 /* This is -*- C -*- */
-/* $Id: guppi-axis-markers.c,v 1.20 2001/11/19 05:40:44 trow Exp $ */
+/* $Id: guppi-axis-markers.c,v 1.24 2002/01/21 03:19:05 trow Exp $ */
 
 /*
  * guppi-axis-markers.c
@@ -32,6 +32,7 @@
 
 #include <stdlib.h>
 #include <math.h>
+#include <string.h>
 
 #include <gtk/gtksignal.h>
 
@@ -475,6 +476,60 @@ guppi_axis_markers_populate_scalar_log (GuppiAxisMarkers * gam,
 
 /* ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** */
 
+/* One less that the Julian day number of 19000101.  */
+static int excel_date_origin = 0;
+
+/*
+ * The serial number of 19000228.  Excel allocates a serial number for
+ * the non-existing date 19000229.
+ */
+static const int excel_date_serial_19000228 = 59;
+
+static void
+excel_date_init (void)
+{
+  /* Day 1 means 1st of January of 1900 */
+  GDate date;
+  g_date_set_dmy (&date, 1, 1, 1900);
+  excel_date_origin = g_date_julian (&date) - 1;
+}
+
+static gboolean
+guppi_date_set_excel (GDate *dst, int serial)
+{
+  if (excel_date_origin == 0)
+    excel_date_init ();
+
+  if (serial > excel_date_serial_19000228) {
+    if (serial == excel_date_serial_19000228 + 1)
+      g_warning ("Request for date 19000229.");
+    serial--;
+  }
+  serial += excel_date_origin;
+  if (! g_date_valid_julian (serial))
+    return FALSE;
+  g_date_set_julian (dst, serial);
+  return TRUE;
+}
+
+static void
+guppi_axis_markers_adjust_excel (GuppiAxisMarkers * gam)
+{
+  int i;
+  double julian;
+  g_return_if_fail (gam != NULL);
+
+  if (!excel_date_origin)
+    excel_date_init ();
+
+  for (i = 0 ; i < gam->N ; ++i) {
+    julian = gam->ticks[i].position - excel_date_origin;
+    gam->ticks[i].position = julian + (julian > excel_date_serial_19000228 ? 1 : 0);
+  }
+
+  changed (gam);
+}
+
 static void
 populate_dates_daily (GuppiAxisMarkers *gam,
 		      GDate *min, GDate *max)
@@ -628,7 +683,8 @@ populate_dates_yearly (GuppiAxisMarkers *gam,
 
 void
 guppi_axis_markers_populate_dates (GuppiAxisMarkers *gam,
-				   GDate *min, GDate *max)
+				   GDate *min, GDate *max,
+				   gboolean do_excel_adjustment)
 {
   gint jspan;
 
@@ -652,6 +708,8 @@ guppi_axis_markers_populate_dates (GuppiAxisMarkers *gam,
   else
     populate_dates_yearly (gam, min, max);
 
+  if (do_excel_adjustment)
+    guppi_axis_markers_adjust_excel (gam);
   guppi_axis_markers_thaw (gam);
 }
 
@@ -689,8 +747,8 @@ guppi_axis_markers_populate_generic (GuppiAxisMarkers *gam,
       gint ja, jb;
       GDate dt_a, dt_b;
 
-      ja = (gint)floor (a);
-      jb = (gint)ceil (b);
+      ja = (gint)floor (a + DBL_EPSILON);
+      jb = (gint)ceil (b - DBL_EPSILON);
 
       if (ja <= 0 || jb <= 0)
 	return;
@@ -701,7 +759,19 @@ guppi_axis_markers_populate_generic (GuppiAxisMarkers *gam,
       g_date_set_julian (&dt_a, ja);
       g_date_set_julian (&dt_b, jb);
             
-      guppi_axis_markers_populate_dates (gam, &dt_a, &dt_b);
+      guppi_axis_markers_populate_dates (gam, &dt_a, &dt_b, FALSE);
+    }
+    break;
+
+  case GUPPI_AXIS_XL_DATE: 
+    {
+      GDate dt_a, dt_b;
+      gint ja = (gint)floor (a + DBL_EPSILON);
+      gint jb = (gint)ceil (b - DBL_EPSILON);
+
+      if (!guppi_date_set_excel (&dt_a, ja) || !guppi_date_set_excel (&dt_b, jb))
+	return;
+      guppi_axis_markers_populate_dates (gam, &dt_a, &dt_b, TRUE);
     }
     break;
 
@@ -756,4 +826,4 @@ guppi_axis_markers_max_label_size (GuppiAxisMarkers * gam, GnomeFont * f,
 }
 
 
-/* $Id: guppi-axis-markers.c,v 1.20 2001/11/19 05:40:44 trow Exp $ */
+/* $Id: guppi-axis-markers.c,v 1.24 2002/01/21 03:19:05 trow Exp $ */
