@@ -1,10 +1,11 @@
 /* This is -*- C -*- */
-/* $Id: guppi-canvas-group.h,v 1.6 2001/01/16 23:36:25 trow Exp $ */
+/* $Id: guppi-canvas-group.h,v 1.9 2001/11/19 05:40:44 trow Exp $ */
 
 /*
  * guppi-canvas-group.h
  *
  * Copyright (C) 2000 EMC Capital Management, Inc.
+ * Copyright (C) 2001 The Free Software Foundation
  *
  * Developed by Jon Trowbridge <trow@gnu.org> and
  * Havoc Pennington <hp@pobox.com>.
@@ -29,9 +30,9 @@
 #define _INC_GUPPI_CANVAS_GROUP_H
 
 /* #include <gnome.h> */
-#include <guppi-canvas-item.h>
+#include  "guppi-canvas-item.h"
 
-#include <guppi-defs.h>
+#include  "guppi-defs.h"
 
 BEGIN_GUPPI_DECLS 
 
@@ -45,6 +46,9 @@ struct _GuppiCanvasGroup {
 
 struct _GuppiCanvasGroupClass {
   GuppiCanvasItemClass parent_class;
+
+  void (*add_hook) (GuppiCanvasGroup *grp, GuppiCanvasItem *item);
+  void (*remove_hook) (GuppiCanvasGroup *grp, GuppiCanvasItem *item);
 };
 
 #define GUPPI_TYPE_CANVAS_GROUP (guppi_canvas_group_get_type())
@@ -60,13 +64,13 @@ GtkType guppi_canvas_group_get_type (void);
 GuppiCanvasItem *guppi_canvas_group_find_by_view (GuppiCanvasGroup *,
 						  GuppiElementView *);
 
-void
-  guppi_canvas_group_foreach_item (GuppiCanvasGroup *,
-				   GuppiCanvasItemFunc, gpointer);
+void guppi_canvas_group_foreach_item (GuppiCanvasGroup *, GuppiCanvasItemFunc, gpointer);
+
+void guppi_canvas_group_auto_position_all (GuppiCanvasGroup *);
 
 
 END_GUPPI_DECLS
 
 #endif /* _INC_GUPPI_CANVAS_GROUP_H */
 
-/* $Id: guppi-canvas-group.h,v 1.6 2001/01/16 23:36:25 trow Exp $ */
+/* $Id: guppi-canvas-group.h,v 1.9 2001/11/19 05:40:44 trow Exp $ */
