@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-element-state.c,v 1.35 2001/11/20 03:40:57 trow Exp $ */
+/* $Id: guppi-element-state.c,v 1.37 2002/01/08 23:19:19 trow Exp $ */
 
 /*
  * guppi-element-state.c
@@ -224,7 +224,7 @@ guppi_element_state_new (const gchar *type, ...)
 
   /* Apply our args */
   va_start (args, type);
-  guppi_attribute_bag_vset (priv (state)->attr_bag, args);
+  guppi_attribute_bag_vset (priv (state)->attr_bag, &args);
   va_end (args);
 
   return state;
@@ -468,24 +468,17 @@ GuppiConfigModel *
 guppi_element_state_make_config_model (GuppiElementState *state)
 {
   GuppiElementStateClass *klass;
-  GuppiConfigModel *cm = NULL, *parent_cm = NULL;
+  GuppiConfigModel *model;
 
   g_return_val_if_fail (GUPPI_IS_ELEMENT_STATE (state), NULL);
 
+  model = guppi_config_model_new ();
+
   klass = GUPPI_ELEMENT_STATE_CLASS (GTK_OBJECT (state)->klass);
   if (klass->make_config_model)
-    cm = klass->make_config_model (state);
+    klass->make_config_model (state, model);
 
-  if (GUPPI_ELEMENT_STATE_CLASS (parent_class)->make_config_model)
-    parent_cm = GUPPI_ELEMENT_STATE_CLASS (parent_class)->make_config_model (state);
-
-  if (cm && parent_cm) {
-    guppi_config_model_combine (parent_cm, NULL, cm);
-    guppi_unref (cm);
-    return parent_cm;
-  }
-
-  return cm ? cm : parent_cm;
+  return model;
 }
 
 /* ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** */
@@ -593,4 +586,4 @@ guppi_element_state_spew_xml (GuppiElementState *state)
   guppi_xml_document_free (doc);
 }
 
-/* $Id: guppi-element-state.c,v 1.35 2001/11/20 03:40:57 trow Exp $ */
+/* $Id: guppi-element-state.c,v 1.37 2002/01/08 23:19:19 trow Exp $ */
