@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-element-view.c,v 1.59 2001/11/21 03:38:40 trow Exp $ */
+/* $Id: guppi-element-view.c,v 1.62 2002/01/14 05:01:20 trow Exp $ */
 
 /*
  * guppi-element-view.c
@@ -189,12 +189,10 @@ print (GuppiElementView *view, GnomePrintContext *pc)
   y0 = guppi_geometry_bottom (geom);
   y1 = guppi_geometry_top (geom);
 
-#if 0
   g_message ("printing %s[%s] %g:%g %g:%g",
 	     gtk_type_name (GTK_OBJECT_TYPE (view)),
 	     guppi_element_view_get_label (view),
 	     x0, x1, y0, y1);
-#endif
 			    
   ep = guppi_element_view_make_print (view, pc);
 
@@ -217,7 +215,7 @@ guppi_element_view_new (GuppiElementState *state, ...)
 
   view = guppi_element_state_make_view (state);
   va_start (args, state);
-  guppi_attribute_bag_vset (priv (view)->attr_bag, args);
+  guppi_attribute_bag_vset (priv (view)->attr_bag, &args);
   va_end (args);
 
   return view;
@@ -1069,7 +1067,9 @@ guppi_element_view_print (GuppiElementView *view, GnomePrintContext *pc)
   g_return_if_fail (pc != NULL && GNOME_IS_PRINT_CONTEXT (pc));
 
   klass = GUPPI_ELEMENT_VIEW_CLASS (GTK_OBJECT (view)->klass);
-  if (klass->print)
+  if (klass->print
+      && view->priv->geometry
+      && guppi_geometry_positioned (view->priv->geometry))
     klass->print (view, pc);
 }
 
@@ -1302,30 +1302,26 @@ guppi_element_view_thaw (GuppiElementView *view)
 GuppiConfigModel *
 guppi_element_view_make_config_model (GuppiElementView *view)
 {
-  GuppiElementViewClass *klass;
-  GuppiConfigModel *cm = NULL, *state_cm = NULL, *parent_cm = NULL, *final_cm;
+  GuppiElementState *state;
+  GuppiElementViewClass *view_class;
+  GuppiElementStateClass *state_class;
+  GuppiConfigModel *model;
+
   g_return_val_if_fail (GUPPI_IS_ELEMENT_VIEW (view), NULL);
 
-  klass = GUPPI_ELEMENT_VIEW_CLASS (GTK_OBJECT (view)->klass);
-  if (klass->make_config_model)
-    cm = klass->make_config_model (view);
+  state = guppi_element_view_state (view);
 
-  if (GUPPI_ELEMENT_VIEW_CLASS (parent_class)->make_config_model)
-    parent_cm = GUPPI_ELEMENT_VIEW_CLASS (parent_class)->make_config_model (view);
+  model = guppi_config_model_new ();
 
-  state_cm = guppi_element_state_make_config_model (guppi_element_view_state (view));
+  view_class = GUPPI_ELEMENT_VIEW_CLASS (GTK_OBJECT (view)->klass);
+  state_class = GUPPI_ELEMENT_STATE_CLASS (GTK_OBJECT (guppi_element_view_state (view))->klass);
 
-  final_cm = guppi_config_model_new ();
+  if (view_class->make_config_model)
+    view_class->make_config_model (view, model);
+  if (state_class->make_config_model)
+    state_class->make_config_model (state, model);
 
-  guppi_config_model_combine (final_cm, NULL, parent_cm);
-  guppi_config_model_combine (final_cm, NULL, state_cm);
-  guppi_config_model_combine (final_cm, NULL, cm);
-
-  guppi_unref (parent_cm);
-  guppi_unref (state_cm);
-  guppi_unref (cm);
-
-  return final_cm;
+  return model;
 }
 
 /* ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** */
@@ -1683,4 +1679,4 @@ GtkType guppi_element_view_get_type (void)
 }
 
 
-/* $Id: guppi-element-view.c,v 1.59 2001/11/21 03:38:40 trow Exp $ */
+/* $Id: guppi-element-view.c,v 1.62 2002/01/14 05:01:20 trow Exp $ */
