@@ -1,9 +1,10 @@
-/* $Id: guppi-marker.h,v 1.8 2001/05/04 16:54:27 mathieu Exp $ */
+/* $Id: guppi-marker.h,v 1.13 2002/01/14 05:01:20 trow Exp $ */
 
 /*
  * guppi-marker.h
  *
  * Copyright (C) 2000 EMC Capital Management, Inc.
+ * Copyright (C) 2001 The Free Software Foundation
  *
  * Developed by Jon Trowbridge <trow@gnu.org>.
  *
@@ -28,10 +29,11 @@
 
 /* #include <gnome.h> */
 #include <libgnomeprint/gnome-print.h>
-#include <guppi-element-print.h>
+#include  "guppi-element-print.h"
 #include "guppi-alpha-template.h"
+#include "guppi-pixbuf.h"
 
-#include <guppi-defs.h>
+#include  "guppi-defs.h"
 
 BEGIN_GUPPI_DECLS 
 
@@ -45,15 +47,13 @@ typedef enum {
   GUPPI_MARKER_X,
   GUPPI_MARKER_SQUARE,
   GUPPI_MARKER_AST,
-  /* commented out to make gtkdoc happy.
-#if 0
-  GUPPI_MARKER_PIXEL,
-  GUPPI_MARKER_DOT,
-#endif
-  */
+  GUPPI_MARKER_TRIANGLE,
+  GUPPI_MARKER_BAR,
+  GUPPI_MARKER_HALF_BAR,
   GUPPI_MARKER_FILLED_CIRCLE,
   GUPPI_MARKER_FILLED_SQUARE,
   GUPPI_MARKER_FILLED_DIAMOND,
+  GUPPI_MARKER_FILLED_TRIANGLE,
   GUPPI_MARKER_LAST,
   GUPPI_MARKER_UNKNOWN
 } GuppiMarker;
@@ -79,6 +79,9 @@ GuppiMarker guppi_str2marker (const gchar *);
 GuppiAlphaTemplate *guppi_marker_alpha_template (GuppiMarker m,
 						 double sz1, double sz2,
 						 double scale_factor);
+GuppiPixbuf *guppi_marker_pixbuf (GuppiMarker m,
+				  double sz1, double sz2,
+				  double scale_factor);
 
 void guppi_marker_print (GuppiMarker m, double sz1, double sz2,
 			 GuppiElementPrint *, double x, double y);
@@ -89,4 +92,4 @@ END_GUPPI_DECLS
 
 #endif /* _INC_GUPPI_MARKER_H */
 
-/* $Id: guppi-marker.h,v 1.8 2001/05/04 16:54:27 mathieu Exp $ */
+/* $Id: guppi-marker.h,v 1.13 2002/01/14 05:01:20 trow Exp $ */
