@@ -1,9 +1,10 @@
-/* $Id: guppi-plot-init.h,v 1.6 2000/10/27 18:23:00 trow Exp $ */
+/* $Id: guppi-plot-init.h,v 1.8 2001/11/19 05:40:44 trow Exp $ */
 
 /*
  * guppi-plot-init.h
  *
  * Copyright (C) 2000 EMC Capital Management, Inc.
+ * Copyright (C) 2001 The Free Software Foundation
  *
  * Developed by Jon Trowbridge <trow@gnu.org>
  * and Havoc Pennington <hp@pobox.com>.
@@ -27,7 +28,7 @@
 #ifndef _INC_GUPPI_PLOT_INIT_H
 #define _INC_GUPPI_PLOT_INIT_H
 
-#include <guppi-defs.h>
+#include  "guppi-defs.h"
 
 BEGIN_GUPPI_DECLS 
 
@@ -37,4 +38,4 @@ END_GUPPI_DECLS
 
 #endif /* _INC_GUPPI_PLOT-INIT_H */
 
-/* $Id: guppi-plot-init.h,v 1.6 2000/10/27 18:23:00 trow Exp $ */
+/* $Id: guppi-plot-init.h,v 1.8 2001/11/19 05:40:44 trow Exp $ */
