@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-raster-text.c,v 1.10 2001/05/06 08:26:43 trow Exp $ */
+/* $Id: guppi-raster-text.c,v 1.15 2001/10/18 21:47:14 jody Exp $ */
 
 /*
  * guppi-raster-text.c
@@ -27,11 +27,13 @@
  */
 
 #include <config.h>
+#include "guppi-raster-text.h"
+
 #include <math.h>
 #include <libart_lgpl/libart.h>
 #include <guppi-convenient.h>
 #include <guppi-metrics.h>
-#include "guppi-raster-text.h"
+
 
 typedef struct _GuppiRasterTextPrivate GuppiRasterTextPrivate;
 struct _GuppiRasterTextPrivate {
@@ -48,30 +50,6 @@ struct _GuppiRasterTextPrivate {
 
 static GtkObjectClass *parent_class = NULL;
 
-enum {
-  ARG_0
-};
-
-static void
-guppi_raster_text_get_arg (GtkObject *obj, GtkArg *arg, guint arg_id)
-{
-  switch (arg_id) {
-
-  default:
-    break;
-  };
-}
-
-static void
-guppi_raster_text_set_arg (GtkObject *obj, GtkArg *arg, guint arg_id)
-{
-  switch (arg_id) {
-
-  default:
-    break;
-  };
-}
-
 static void
 guppi_raster_text_finalize (GtkObject * obj)
 {
@@ -97,15 +75,13 @@ guppi_raster_text_class_init (GuppiRasterTextClass *klass)
 
   parent_class = gtk_type_class (GTK_TYPE_OBJECT);
 
-  object_class->get_arg = guppi_raster_text_get_arg;
-  object_class->set_arg = guppi_raster_text_set_arg;
   object_class->finalize = guppi_raster_text_finalize;
 }
 
 static void
 guppi_raster_text_init (GuppiRasterText *obj)
 {
-  GuppiRasterTextPrivate *p = g_new0 (GuppiRasterTextPrivate, 1);
+  GuppiRasterTextPrivate *p = guppi_new0 (GuppiRasterTextPrivate, 1);
 
   p->scale = -1;
 
@@ -133,8 +109,8 @@ GtkType guppi_raster_text_get_type (void)
 static void
 underlying_text_changed (GuppiTextBlock *text, GuppiRasterText *raster)
 {
-  g_return_unless_is_guppi_text_block (text);
-  g_return_if_fail (raster && GUPPI_IS_RASTER_TEXT (raster));
+  g_return_if_fail (GUPPI_IS_TEXT_BLOCK (text));
+  g_return_if_fail (GUPPI_IS_RASTER_TEXT (raster));
   guppi_unref0 (priv (raster)->template);
 }
 
@@ -144,8 +120,7 @@ guppi_raster_text_new (GuppiTextBlock *text)
   GuppiRasterText *raster;
   GuppiRasterTextPrivate *p;
 
-  if (text)
-    g_return_val_unless_is_guppi_text_block (text, NULL);
+  g_return_val_if_fail (text == NULL || GUPPI_IS_TEXT_BLOCK (text), NULL);
 
   raster = GUPPI_RASTER_TEXT (guppi_type_new (guppi_raster_text_get_type ()));
   p = priv (raster);
@@ -345,7 +320,7 @@ guppi_raster_text_position (GuppiRasterText *rt, gint *x, gint *y)
 
 /* ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** */
 
-const gchar *
+gchar *
 guppi_raster_text_text (GuppiRasterText *rt)
 {
   g_return_val_if_fail (rt && GUPPI_IS_RASTER_TEXT (rt), NULL);
@@ -380,4 +355,4 @@ guppi_raster_text_set_angle (GuppiRasterText *rt, double angle)
 
 
 
-/* $Id: guppi-raster-text.c,v 1.10 2001/05/06 08:26:43 trow Exp $ */
+/* $Id: guppi-raster-text.c,v 1.15 2001/10/18 21:47:14 jody Exp $ */
