@@ -1,9 +1,10 @@
-/* $Id: guppi-root-group-tools.h,v 1.6 2001/01/16 23:36:34 trow Exp $ */
+/* $Id: guppi-root-group-tools.h,v 1.9 2001/11/20 03:40:58 trow Exp $ */
 
 /*
  * guppi-root-group-tools.h
  *
  * Copyright (C) 2000 EMC Capital Management, Inc.
+ * Copyright (C) 2001 The Free Software Foundation
  *
  * Developed by Jon Trowbridge <trow@gnu.org>.
  *
@@ -30,12 +31,10 @@
 #include "guppi-plot-tool.h"
 #include "guppi-plot-toolkit.h"
 
-#include <guppi-defs.h>
+#include "guppi-defs.h"
 
 BEGIN_GUPPI_DECLS
 
-GuppiPlotTool * guppi_root_group_tool_new_show_configure (void);
-GuppiPlotTool *guppi_root_group_tool_new_select_and_configure (void);
 GuppiPlotTool *guppi_root_group_tool_new_help (void);
 
 GuppiPlotToolkit *guppi_root_group_toolkit_configure (void);
@@ -44,4 +43,4 @@ END_GUPPI_DECLS
 
 #endif /* _INC_GUPPI_ROOT_GROUP_TOOLS_H */
 
-/* $Id: guppi-root-group-tools.h,v 1.6 2001/01/16 23:36:34 trow Exp $ */
+/* $Id: guppi-root-group-tools.h,v 1.9 2001/11/20 03:40:58 trow Exp $ */
