@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-root-group-view.c,v 1.14 2001/11/20 03:58:43 trow Exp $ */
+/* $Id: guppi-root-group-view.c,v 1.16 2002/01/19 02:45:21 trow Exp $ */
 
 /*
  * guppi-root-group-view.c
@@ -51,8 +51,6 @@ static GtkObjectClass *parent_class = NULL;
 static void
 guppi_root_group_view_destroy (GtkObject *obj)
 {
-  GuppiRootGroupView *view = GUPPI_ROOT_GROUP_VIEW (obj);
-
   if (parent_class->destroy)
     parent_class->destroy (obj);
 }
@@ -244,6 +242,7 @@ guppi_root_group_view_set_size (GuppiRootGroupView *view, double w, double h)
     view->width = w;
     view->height = h;
 
+    guppi_element_view_changed_size (GUPPI_ELEMENT_VIEW (view), view->width, view->height);
     guppi_geometry_set_position (geom, 0, view->width, 0, view->height);
   }
 }
@@ -262,4 +261,4 @@ guppi_root_group_view_height (GuppiRootGroupView *view)
   return view->height;
 }
 
-/* $Id: guppi-root-group-view.c,v 1.14 2001/11/20 03:58:43 trow Exp $ */
+/* $Id: guppi-root-group-view.c,v 1.16 2002/01/19 02:45:21 trow Exp $ */
