@@ -1,4 +1,4 @@
-/* $Id: guppi-stat-init.c,v 1.7 2001/05/06 00:07:38 trow Exp $ */
+/* $Id: guppi-stat-init.c,v 1.8 2002/01/14 05:01:22 trow Exp $ */
 
 /*
  * guppi-stat-init.c
@@ -25,24 +25,13 @@
  */
 
 #include <config.h>
-#include <guppi-guile.h>
-#include "guppi-scm-stat.h"
 #include "guppi-stat-init.h"
 
-#ifdef HAVE_PYTHON
-void guppi_python_stat_init (void);
-#endif
-
 void
 guppi_stat_init (void)
 {
-  if (guppi_guile_is_active ())
-    guppi_scm_stat_init ();
 
-#ifdef HAVE_PYTHON
-  guppi_python_stat_init ();
-#endif
 }
 
 
-/* $Id: guppi-stat-init.c,v 1.7 2001/05/06 00:07:38 trow Exp $ */
+/* $Id: guppi-stat-init.c,v 1.8 2002/01/14 05:01:22 trow Exp $ */
