@@ -1,4 +1,4 @@
-/* $Id: guppi-debug.h,v 1.13 2001/09/21 22:50:28 trow Exp $ */
+/* $Id: guppi-debug.h,v 1.14 2001/11/19 05:40:52 trow Exp $ */
 
 /*
  * guppi-debug.h
@@ -30,7 +30,7 @@
 
 /* #include <gtk/gtk.h> */
 
-#include <guppi-defs.h>
+#include  "guppi-defs.h"
 #include <glib.h>
 
 BEGIN_GUPPI_DECLS
@@ -156,4 +156,4 @@ END_GUPPI_DECLS
 
 #endif /* _INC_GUPPI_DEBUG_H */
 
-/* $Id: guppi-debug.h,v 1.13 2001/09/21 22:50:28 trow Exp $ */
+/* $Id: guppi-debug.h,v 1.14 2001/11/19 05:40:52 trow Exp $ */
