@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-stream.c,v 1.15 2001/05/06 08:26:46 trow Exp $ */
+/* $Id: guppi-stream.c,v 1.17 2001/09/08 05:50:00 trow Exp $ */
 
 /*
  * guppi-stream.c
@@ -26,13 +26,14 @@
  */
 
 #include <config.h>
+#include "guppi-stream.h"
+
 #include <sys/stat.h>
 #include <string.h>
 
 #include <gtk/gtksignal.h>
-
 #include <guppi-convenient.h>
-#include "guppi-stream.h"
+
 
 static GtkObjectClass *parent_class = NULL;
 
@@ -44,39 +45,8 @@ enum {
 };
 static guint str_signals[LAST_SIGNAL] = { 0 };
 
-enum {
-  ARG_0
-};
-
 static void
-guppi_stream_get_arg (GtkObject * obj, GtkArg * arg, guint arg_id)
-{
-  switch (arg_id) {
-
-  default:
-    break;
-  };
-}
-
-static void
-guppi_stream_set_arg (GtkObject * obj, GtkArg * arg, guint arg_id)
-{
-  switch (arg_id) {
-
-  default:
-    break;
-  };
-}
-
-static void
-guppi_stream_destroy (GtkObject * obj)
-{
-  if (parent_class->destroy)
-    parent_class->destroy (obj);
-}
-
-static void
-guppi_stream_finalize (GtkObject * obj)
+guppi_stream_finalize (GtkObject *obj)
 {
   GuppiStream *gs = GUPPI_STREAM (obj);
   gint i;
@@ -112,7 +82,7 @@ guppi_stream_finalize (GtkObject * obj)
 }
 
 static void
-guppi_stream_class_init (GuppiStreamClass * klass)
+guppi_stream_class_init (GuppiStreamClass *klass)
 {
   GtkObjectClass *object_class = (GtkObjectClass *) klass;
 
@@ -145,15 +115,11 @@ guppi_stream_class_init (GuppiStreamClass * klass)
   klass->fully_preloaded = NULL;
   klass->changed_codes = NULL;
 
-  object_class->get_arg = guppi_stream_get_arg;
-  object_class->set_arg = guppi_stream_set_arg;
-  object_class->destroy = guppi_stream_destroy;
   object_class->finalize = guppi_stream_finalize;
-
 }
 
 static void
-guppi_stream_init (GuppiStream * gs)
+guppi_stream_init (GuppiStream *gs)
 {
   gs->in = NULL;
 
@@ -207,7 +173,7 @@ guppi_stream_get_type (void)
 }
 
 GuppiStream *
-guppi_stream_new (GuppiFile * f)
+guppi_stream_new (GuppiFile *f)
 {
   GuppiStream *gs;
   struct stat stat;
@@ -227,7 +193,7 @@ guppi_stream_new (GuppiFile * f)
 }
 
 GuppiStream *
-guppi_stream_open_file (const gchar * filename)
+guppi_stream_open_file (const gchar *filename)
 {
   GuppiFile *in;
   GuppiStream *gs;
@@ -247,8 +213,8 @@ guppi_stream_open_file (const gchar * filename)
 /**********************************************************************/
 
 static gboolean
-guppi_stream_mark_line (GuppiStream * gs,
-			const gchar * line, gchar * buffer, gint buffer_len)
+guppi_stream_mark_line (GuppiStream *gs,
+			const gchar *line, gchar *buffer, gint buffer_len)
 {
   gboolean injected_escape, in_comment, in_quote, punch_in;
   gint p = 0, i, j;
@@ -352,8 +318,8 @@ guppi_stream_mark_line (GuppiStream * gs,
 }
 
 static gboolean
-guppi_stream_sanitize_line (GuppiStream * gs,
-			    const gchar * line, gchar * sani, gint sani_len)
+guppi_stream_sanitize_line (GuppiStream *gs,
+			    const gchar *line, gchar *sani, gint sani_len)
 {
   gint i = 0, j = 0;
   gboolean seen_escape;
@@ -414,7 +380,7 @@ guppi_stream_sanitize_line (GuppiStream * gs,
 /**********************************************************************/
 
 static void
-guppi_stream_changed (GuppiStream * gs)
+guppi_stream_changed (GuppiStream *gs)
 {
   const gint buflen = 1024;
   gchar mbuf[1024];
@@ -446,7 +412,7 @@ guppi_stream_changed (GuppiStream * gs)
 }
 
 gboolean
-guppi_stream_sequential_mode (GuppiStream * gs)
+guppi_stream_sequential_mode (GuppiStream *gs)
 {
   g_return_val_if_fail (gs != NULL, FALSE);
 
@@ -454,7 +420,7 @@ guppi_stream_sequential_mode (GuppiStream * gs)
 }
 
 void
-guppi_stream_set_sequential_mode (GuppiStream * gs)
+guppi_stream_set_sequential_mode (GuppiStream *gs)
 {
   g_return_if_fail (gs != NULL);
   g_return_if_fail (gs->buffering);
@@ -463,14 +429,14 @@ guppi_stream_set_sequential_mode (GuppiStream * gs)
 }
 
 const gchar *
-guppi_stream_eol_comment (const GuppiStream * gs)
+guppi_stream_eol_comment (const GuppiStream *gs)
 {
   g_return_val_if_fail (gs != NULL, NULL);
   return gs->eol_comment;
 }
 
 void
-guppi_stream_set_eol_comment (GuppiStream * gs, const gchar * x)
+guppi_stream_set_eol_comment (GuppiStream *gs, const gchar *x)
 {
   g_return_if_fail (gs != NULL);
 
@@ -487,7 +453,7 @@ guppi_stream_set_eol_comment (GuppiStream * gs, const gchar * x)
 }
 
 const gchar *
-guppi_stream_ml_comment_start (const GuppiStream * gs)
+guppi_stream_ml_comment_start (const GuppiStream *gs)
 {
   g_return_val_if_fail (gs != NULL, NULL);
 
@@ -495,14 +461,14 @@ guppi_stream_ml_comment_start (const GuppiStream * gs)
 }
 
 const gchar *
-guppi_stream_ml_comment_end (const GuppiStream * gs)
+guppi_stream_ml_comment_end (const GuppiStream *gs)
 {
   g_return_val_if_fail (gs != NULL, NULL);
   return gs->ml_end_comment;
 }
 
 void
-guppi_stream_set_ml_comment_start (GuppiStream * gs, const gchar * x)
+guppi_stream_set_ml_comment_start (GuppiStream *gs, const gchar *x)
 {
   g_return_if_fail (gs != NULL);
 
@@ -519,7 +485,7 @@ guppi_stream_set_ml_comment_start (GuppiStream * gs, const gchar * x)
 }
 
 void
-guppi_stream_set_ml_comment_end (GuppiStream * gs, const gchar * x)
+guppi_stream_set_ml_comment_end (GuppiStream *gs, const gchar *x)
 {
   g_return_if_fail (gs != NULL);
 
@@ -536,21 +502,21 @@ guppi_stream_set_ml_comment_end (GuppiStream * gs, const gchar * x)
 }
 
 gchar
-guppi_stream_quote_start (const GuppiStream * gs)
+guppi_stream_quote_start (const GuppiStream *gs)
 {
   g_return_val_if_fail (gs != NULL, '\0');
   return gs->start_quote;
 }
 
 gchar
-guppi_stream_quote_end (const GuppiStream * gs)
+guppi_stream_quote_end (const GuppiStream *gs)
 {
   g_return_val_if_fail (gs != NULL, '\0');
   return gs->end_quote;
 }
 
 void
-guppi_stream_set_quote_start (GuppiStream * gs, gchar x)
+guppi_stream_set_quote_start (GuppiStream *gs, gchar x)
 {
   g_return_if_fail (gs != NULL);
 
@@ -559,7 +525,7 @@ guppi_stream_set_quote_start (GuppiStream * gs, gchar x)
 }
 
 void
-guppi_stream_set_quote_end (GuppiStream * gs, gchar x)
+guppi_stream_set_quote_end (GuppiStream *gs, gchar x)
 {
   g_return_if_fail (gs != NULL);
 
@@ -568,7 +534,7 @@ guppi_stream_set_quote_end (GuppiStream * gs, gchar x)
 }
 
 gchar
-guppi_stream_escape (const GuppiStream * gs)
+guppi_stream_escape (const GuppiStream *gs)
 {
   g_return_val_if_fail (gs != NULL, '\0');
 
@@ -576,14 +542,14 @@ guppi_stream_escape (const GuppiStream * gs)
 }
 
 const gchar *
-guppi_stream_source (GuppiStream * gs)
+guppi_stream_source (GuppiStream *gs)
 {
   g_return_val_if_fail (gs != NULL, NULL);
   return guppi_file_filename (gs->in);
 }
 
 gint
-guppi_stream_number_of_lines (GuppiStream * gs)
+guppi_stream_number_of_lines (GuppiStream *gs)
 {
   g_return_val_if_fail (gs != NULL, -1);
 
@@ -591,7 +557,7 @@ guppi_stream_number_of_lines (GuppiStream * gs)
 }
 
 gint
-guppi_stream_estimated_number_of_lines (GuppiStream * gs)
+guppi_stream_estimated_number_of_lines (GuppiStream *gs)
 {
   g_return_val_if_fail (gs != NULL, -1);
 
@@ -610,7 +576,7 @@ guppi_stream_estimated_number_of_lines (GuppiStream * gs)
 }
 
 int
-guppi_stream_number_of_preloaded_lines (GuppiStream * gs)
+guppi_stream_number_of_preloaded_lines (GuppiStream *gs)
 {
   g_return_val_if_fail (gs != NULL, -1);
 
@@ -620,7 +586,7 @@ guppi_stream_number_of_preloaded_lines (GuppiStream * gs)
 /* Ensure that the buffer is big enough to accomodate at least minimum_count
    lines. */
 static void
-guppi_stream_grow_buffers (GuppiStream * gs, gint minimum_count)
+guppi_stream_grow_buffers (GuppiStream *gs, gint minimum_count)
 {
   gint new_count;
   gchar **new_buffer;
@@ -656,10 +622,10 @@ guppi_stream_grow_buffers (GuppiStream * gs, gint minimum_count)
 }
 
 static void
-guppi_stream_add_to_buffer (GuppiStream * gs,
-			    const gchar * line,
-			    const gchar * marked_line,
-			    const gchar * sani_line)
+guppi_stream_add_to_buffer (GuppiStream *gs,
+			    const gchar *line,
+			    const gchar *marked_line,
+			    const gchar *sani_line)
 {
   gint i;
 
@@ -682,7 +648,7 @@ guppi_stream_add_to_buffer (GuppiStream * gs,
 
 
 static void
-guppi_stream_get_lines_through (GuppiStream * gs, gint line_no)
+guppi_stream_get_lines_through (GuppiStream *gs, gint line_no)
 {
   const gint buflen = 1024;
   gchar buf[1024];
@@ -746,7 +712,7 @@ guppi_stream_get_lines_through (GuppiStream * gs, gint line_no)
 }
 
 static void
-guppi_stream_line_get_triple (GuppiStream * gs, gint line_no,
+guppi_stream_line_get_triple (GuppiStream *gs, gint line_no,
 			      const gchar ** line,
 			      const gchar ** marked, const gchar ** sani)
 {
@@ -808,7 +774,7 @@ guppi_stream_line_get_triple (GuppiStream * gs, gint line_no,
 }
 
 const gchar *
-guppi_stream_get_line (GuppiStream * gs, gint line_no)
+guppi_stream_get_line (GuppiStream *gs, gint line_no)
 {
   const gchar *x;
 
@@ -818,7 +784,7 @@ guppi_stream_get_line (GuppiStream * gs, gint line_no)
 }
 
 const gchar *
-guppi_stream_get_marked_line (GuppiStream * gs, gint line_no)
+guppi_stream_get_marked_line (GuppiStream *gs, gint line_no)
 {
   const gchar *x;
 
@@ -828,7 +794,7 @@ guppi_stream_get_marked_line (GuppiStream * gs, gint line_no)
 }
 
 const gchar *
-guppi_stream_get_sanitized_line (GuppiStream * gs, gint line_no)
+guppi_stream_get_sanitized_line (GuppiStream *gs, gint line_no)
 {
   const gchar *x;
 
@@ -840,7 +806,7 @@ guppi_stream_get_sanitized_line (GuppiStream * gs, gint line_no)
 /**********************************************************************/
 
 void
-guppi_stream_load_some_lines (GuppiStream * gs)
+guppi_stream_load_some_lines (GuppiStream *gs)
 {
   g_return_if_fail (gs != NULL);
   if (gs->current_line_no < 0)
@@ -848,7 +814,7 @@ guppi_stream_load_some_lines (GuppiStream * gs)
 }
 
 void
-guppi_stream_load_more_lines (GuppiStream * gs)
+guppi_stream_load_more_lines (GuppiStream *gs)
 {
   g_return_if_fail (gs != NULL);
   guppi_stream_get_lines_through (gs, gs->current_line_no + 250);
@@ -857,4 +823,4 @@ guppi_stream_load_more_lines (GuppiStream * gs)
 
 
 
-/* $Id: guppi-stream.c,v 1.15 2001/05/06 08:26:46 trow Exp $ */
+/* $Id: guppi-stream.c,v 1.17 2001/09/08 05:50:00 trow Exp $ */
